/***********/ local filename = "wikidis_ana_PoD_link_position_in_text" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close


include "${PATH_PLUGIN}wikidis_plugin_locals.do"
include "${PATH_EXTRA_PLUGIN}print_execute.do"
log using "${PATH_LOGS}/`filename'.log", replace



**** Short description of do-file:
/* This do file runs a few simple regressions to analyse /*
	*/ the effect of link position on the heterogeneity in attention spillovers
desc_end ***/

local texoutput_file "heterog_slides.tex"
local table_slides_path "${PATH_PAPER_SLIDES}wikidis__auto_slides"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"
cap mkdir `table_stand_alone_path'
local tab_desc_path "${PATH_DESCRIPTIVES_TABLES}"


*foreach linkdistance in L2 {
local linkdistance L1
local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_with_link_position_in_L0.dta"	

use "`startdata'", clear

* drop peak_clicks
* rename net_peak_clicks peak_clicks

* set up a tex-file for viewing all the outputs of this analysis
**********
local includer_name "${PATH_PAPER_VIEWASPDF}wikidis_linkposit_caller.tex"
local file_includer and_table_caller
cap file close `includer_name' 
* cap file erase `includer_name' 
pe file open `file_includer'  using `includer_name', write replace

* DESCRIPTIVE FIGURES
**************
local storepath "${PATH_FIGURES}"
local graphname linkposition_on_click_peaks

local variables_x link_20_aggregator link_position_relative num_repetitions_link /*put several if you wnat real iteration */
local variables_y peak_clicks peak_del_num_revisions peak_del_num_authors /*put several if you wnat real iteration */
* 
local var_extra_category /*does not need to be filled */

local descriptive_plots_yes "yes" /* "yes" or "no" */
if "`descriptive_plots_yes'" == "yes" {

	foreach var_to_plot in `variables_y' {
		local counter_y = `counter_y'+1
		foreach var_x_axis in `variables_x' {
		/* choose order in which you want to iterate by excahnging y and x loop */
			local counter_x = `counter_x'+1
			local graph_file `storepath'`graphname'_`var_x_axis'
			local titletext "`var_to_plot' on `var_x_axis'"
			sum `var_x_axis'
			local xrange = r(max) - r(min)
			local xlim_low = r(min) - `xrange'*0.1 
			local xlim_hi = r(max) + `xrange'*0.1
			pe file write  `file_includer' _n "\subsection{Plots: iteration `counter_y' `counter_x'}" _n
			
			pe by `var_x_axis', sort: sum `var_to_plot'
			cap drop mean_`var_to_plot'
			pe by `var_x_axis' `var_extra_category': egen mean_`var_to_plot' = mean(`var_to_plot')
			
			pe hist `var_x_axis', freq addlabels title(Distribution of `var_x_axis')
			local temp_graph_filename `graph_file'_hist_cont.png
			pe graph export `temp_graph_filename' , replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			pe hist `var_x_axis', discrete freq addlabels title(Distribution of `var_x_axis')
			local temp_graph_filename `graph_file'_hist_categ.png
			pe graph export `temp_graph_filename' , replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 

			sort `var_x_axis' `var_extra_category' start_page_name page_id

			

			** Means of depvar vs. x-axis
			* Clean+Neat alternative
			preserve 
				pe collapse `var_to_plot', by (`var_x_axis' `var_extra_category')
				pe scatter `var_to_plot' `var_x_axis', title(`titletext') connect(direct) mcolor(cranberry) msize(large) /* jitter(20) */
				local temp_graph_filename  `graph_file'_mean_`var_to_plot'.png
				pe graph export `temp_graph_filename', replace
				file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			restore

			* jitter
			pe scatter mean_`var_to_plot' `var_x_axis', xsc(range(`xlim_low' `xlim_hi')) ysc(fextend) title(`titletext' with freq.) /*connect(direct)*/ mcolor(cranberry) msize(vtiny)  jitter(8) 
			local temp_graph_filename `graph_file'_mean_`var_to_plot'_jitter.png
			graph export `temp_graph_filename', replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			
			
			* messy: all dots (no means) of it wit lfit
			pe scatter `var_to_plot' `var_x_axis', title(`titletext' with line-plot) xsc(extend) ysc(extend) /* connect(direct)*/ mcolor(cranberry) msize(vtiny) /*
				*/ || lfit `var_to_plot' `var_x_axis', lwidth(thick)
			local temp_graph_filename `graph_file'_`var_to_plot'.png
			pe graph export `temp_graph_filename', replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			
			
			pe file write  `file_includer' _n "\clearpage" _n
		}
		local counter_x 
	} 
}

local counter_y 


* A simple regression
**********
local link_group_flags flag_link_20_2 flag_link_20_3 flag_link_20_4 flag_link_20_5
* alternative: link_position_in_L0
local other_criteria num_repetitions_link 
	* max_link_position_rel has a surprisingly relevant effect, but I do not understand why
local network_vars  num_L0_links num_links_from_l1 

local heterogen_flags flag_stub flag_long flag_linked flag_super_l1 
local page_chars num_revisions num_authors page_length num_imagelinks SNwik_degree 

** Reg for Paper
**************************

local estlabel "PositionRegs"

local variables_interest A B C
local var_of_interest_A `link_group_flags'
local var_of_interest_B link_position_relative  /* sq_link_position_relative */
local var_of_interest_C link_20_aggregator 

local depvarlist peak_clicks peak_del_num_revisions peak_del_num_authors abs_del_page_length
foreach depvar in `depvarlist' {
	local Cnt = `Cnt'+1 
	foreach A_B_C in `variables_interest' {
		local var_of_interest `var_of_interest_`A_B_C''
		

		/* estimates */
		pe regress `depvar' `var_of_interest'
		estimates store `estlabel'`Cnt'`A_B_C'1
		estadd ysumm

		pe regress `depvar'  `var_of_interest' `page_chars'
		estimates store `estlabel'`Cnt'`A_B_C'2
		estadd ysumm


		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' 
		estimates store `estlabel'`Cnt'`A_B_C'3
		estadd ysumm


		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' `network_vars'  
		estimates store `estlabel'`Cnt'`A_B_C'4
		estadd ysumm  

		pe regress `depvar'  `var_of_interest' `heterogen_flags' `page_chars' `other_criteria' `network_vars' 
		estimates store `estlabel'`Cnt'`A_B_C'5
		estadd ysumm  





			**** objects in table:
			/* check out how many events, pages, observatoins and days are in the dataset  
				and provide that info as local */
				local time  flag_treated		/* add some dummy if it is a crosssection */
				local obs_id page_id		/* specify the adequate variable */
				local cluster_id start_page_name
				
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `estlabel'`Cnt'`A_B_C'1 `estlabel'`Cnt'`A_B_C'2 `estlabel'`Cnt'`A_B_C'3 `estlabel'`Cnt'`A_B_C'4 `estlabel'`Cnt'`A_B_C'5"
			local mgroupsoption 
			/* " "Group 1" "Group 2", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" */
			local columntitles A B C D E
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "Relationship of link position and additional attention. Dependent variable: `depvar'"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "16.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition The first quintile represents the neighbors that are /*
						*/ mentioned among the first 20\% of links in the outgoing page. The third quintile are article /*
						*/ in the middle and the last quintile was linked at the end of the outgoing page. 
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table shows the download frequency for articles grouped by their order of /*
					*/ appearance in the treated article. `notetext_addition' In Column 2 /*
					*/ I control for the article characteristics (length and network-characteristcs), and in Column 3 I control /*
					*/ for the total number of links on the outgoing (L\_0) pages and the abolute number of links /*
					*/ from other neighbors (in L\_1). Column 4 accounts for how often a given link was repeated /*
					*/ on the outgoing site. Column 5 finally introduces more variables that account for articles' /*
					*/ characteristics (length, past amount of contributions, etc.)/*
					*/ The Reference group are links in the 40-60 \% quintile; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'_`depvar'_`A_B_C'.tex"
			local latexlabel `estlabel'`Cnt'`A_B_C' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

					pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N N_g r2_a ymean, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption') /*
				*/ mtitles(`columntitles') /*
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
			
			/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
				* file write  `file_includer' "\begin{landscape}" _n
				file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
				* file write  `file_includer' "\end{landscape}" _n
				file write  `file_includer' _n
			
	}	
	pe file write  `file_includer' _n "\clearpage" _n
	*est clear
}


******************************************
* A Deeper analysis of Link Positions Effect
******************************************


** Define the most relevant Variables
**************************

local main_depvar peak_clicks  flag_activity  abs_del_page_length   
local other_depvars   peak_del_num_authors peak_del_num_revisions del_num_authors del_page_length /* more devars: does not need to be filled - would generate a table each */
local depvarlist `main_depvar' `other_depvars' /**/

local var_extra_category "time_var" /* if you do not want any categries, take a constant value (gen const = 1) */
local sampling_crit "abs_del_page_length > 10 " /* no sampling: set "1==1" */
local sampling_condition "if `sampling_crit'"
local counter_sampling_cond "if (`sampling_crit') == 0 "
 

local var_of_interest_A  flag_link_20_2 flag_link_20_3 flag_link_20_4 flag_link_20_5
** local var_of_interest_A `link_group_flags'
local var_of_interest_C link_position_relative   /*  */
local var_of_interest_B link_20_aggregator
local var_of_interest_D link_position_relative sq_link_position_relative
local other_plot_x_vars /* can remain empty: or contain gender, category or flag_treated if sample is to be distinguished */

local vars_of_interest "`var_of_interest_A' `var_of_interest_B' `var_of_interest_C' `var_of_interest_D'"

local controls_i /* e.g. empty */
	* alternative: link_position_in_L0
local controls_j num_revisions num_authors page_length num_imagelinks SNwik_degree 
local controls_k `controls_j' flag_stub flag_long flag_linked flag_super_l1 
local controls_l `controls_k' num_repetitions_link num_L0_links num_links_from_l1 /* e.g. empty */

local reg_controls `controls_i' `controls_j' `controls_k' `controls_l'

local vars_for_sumstats `depvarlist' `var_extra_category' `vars_of_interest' `reg_controls'  
local vars_to_summarize `depvarlist' `var_extra_category' `vars_of_interest' `reg_controls'  
local vars_to_correlate `depvarlist' `var_extra_category' `vars_of_interest' 


** identify outliers
**************************
local outlier_vars `depvarlist' `vars_of_interest'
cap drop flag_outlier 
gen flag_outlier = 0
foreach var in `outlier_vars' {
	centile `var' `sampling_condition', centile(99 98.0 99.5)
	di int(r(c_3))
	replace flag_outlier = 1 if `var' > int(r(c_2))
	}

local no_outlier_extension "& flag_outlier == 0" /* & flag_outlier == 0 */ 

** IF conditions that reduce observation set for the entire estimation and data description
***********************************
local if_condition_1 "" /* possibly a `sampling_condition' - "if 1==1" => full sample */ 
local if_condition_2 `if_condition_1' if `sampling_crit' `no_outlier_extension' /*`no_outlier_extension' */  /* by default: local if_condition_2 `if_condition_1' - change if otherwise desired */
** possible but not intended:  local if_condition_3 `if_condition_1'  /* by default: local if_condition_2 `if_condition_1' - change if otherwise desired */


*********************
* DESCRIPTIVE TABLES
*********************
local desc_tabs_path  `tab_desc_path' /* path for descriptive tables */
local vars_to_summarize `vars_for_sumstats'
	/* vars_for_sumstats is defined in template_standard_analysis 
		-- alternatively define before calling here (if you call (or worse: copy-pasted) just the sumstats part... */
		
	pe file write  `file_includer' _n "\section{DESCRIPTIVE TABLES}" _n 

	***
	dis "* All Observation in Sample"
	***
	aorder
	sum `vars_to_summarize'
		local sumstatfilename "`desc_tabs_path'`filename'`TableNameLabel'.tex"

		local TableNameLabel "FullSample" /* don't change the name of local if you wnat the label in latex) !! */
		local titletext "Summary statistics: `TableNameLabel'  of main variables"
		local sumstats_table_file "`desc_tabs_path'`filename'_desc_`TableNameLabel'.tex"

		estpost summarize `vars_to_summarize' , detail   
		esttab  . using "`sumstats_table_file'" , /*
			*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p50(fmt(%11.2g))  p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
			*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
			*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
			*/ booktabs replace  /*
			*/ order(`stand_varorder')	/*
			*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" )
			

			
	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */

		* file write  `file_includer' "\begin{landscape}" _n
		pe file write  `file_includer' _n "\input{`sumstats_table_file'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		pe file write  `file_includer' _n
		
	
	dis "*** subsample " 

		local TableNameLabel "Subsample" /* don't change the name of local if you wnat the label in latex) !! */
		local titletext "Summary statistics: `TableNameLabel'  of main variables `sampling_condition'"
		local sumstats_table_file "`desc_tabs_path'`filename'_desc_`TableNameLabel'.tex"
		
		* version for and_overiew
		estpost summarize `vars_to_summarize' `sampling_condition', detail   
		esttab  . using "`sumstats_table_file'" , /*
			*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p50(fmt(%11.2g))  p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
			*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
			*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
			*/ booktabs replace  /*
			*/ order(`stand_varorder') /*
			*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" )
			
	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */

		* file write  `file_includer' "\begin{landscape}" _n
		pe file write  `file_includer' _n "\input{`sumstats_table_file'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		pe file write  `file_includer' _n

			
	dis "*** COUNTER SUBSAMPLE" 
	count `counter_sampling_cond'
	if r(N) > 0 {
		local TableNameLabel "CounterSample" /* don't change the name of local if you wnat the label in latex) !! */
		local titletext "Summary statistics: `TableNameLabel'  of main variables `counter_sampling_cond'"
		local sumstats_table_file "`desc_tabs_path'`filename'_desc_`TableNameLabel'.tex"
		
		* version for and_overiew
		estpost summarize `vars_to_summarize' `counter_sampling_cond', detail   
		esttab  . using "`sumstats_table_file'", /*
			*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p50(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
			*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
			*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
			*/ booktabs replace  /*
			*/ order(`stand_varorder') /*
			*/ coeflabels(`varname_labels') /*
			*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" )  
				

	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */

		* file write  `file_includer' "\begin{landscape}" _n
		file write  `file_includer' _n "\input{`sumstats_table_file'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		file write  `file_includer' _n
	}
	/* version for slides
	local sumstats_table_file "${PATH_PAIRS_DESC_TABLES}`filename'`TableNameLabel'_CounterSample.tex"
	estpost summarize `vars_to_summarize' `if_condition', detail   
	esttab  . using "`sumstats_table_file'" , /*
		*/ cells("count mean(fmt(%11.2g)) sd(fmt(%11.2g)) min(fmt(%11.2g)) p10(fmt(%11.2g)) p90(fmt(%11.2g)) max(fmt(%11.2g))")   /*
		*/ align(|crrrrrrr) /* note: align has to have two more columns than cells!!
		*/ noobs title(`titletext' \label{tab:`TableNameLabel'}) nonumber not star compress /*
		*/ booktabs replace  /*
		*/ order(`stand_varorder') */
	
	
	
* A simple regression for deeper analysis of Link Positions Effect
**************************

*** Alternative measures of Link Position 
***********************


	pe file write  `file_includer' _n "\section{Link Positions Effect regressions}" _n

	local estlabel "LinkPositMeasures"
	
	local reg_command regress
	
	local reg_options_1 ", robust" /**/
	local reg_options_2 `reg_options_1' /* by default: local options_2 `options_1' - change if otherwise desired */
	** local reg_options_3 `options_1' /* by default: local options_2 `options_1' - change if otherwise desired */

local auto_reg_list = "" /* container leeren */
local auto_column_titles ""
pe local auto_groups ""

foreach depvar in peak_clicks {
	local variables_interest B C D
		/* A B C D */
	local controls_interest i l
		/* i j k l */
		/* careful!, only 1 loop expected at the bottom, 
			=> make sure to deactivate the i_j_k loop if you wnat to iterate over vars of interest...
			=> for additional table per var of interest add options B C etc..... */
	foreach A_B_C in `variables_interest' { 

		* foreach variant_of_reg in 1 2  { 
			/* default 2 */ 
			local variant_of_reg 1 
			local counter_rd = 1
			foreach i_j_k in `controls_interest'{
			
				** specify controls, options and label.
				local var_x_in_reg `var_of_interest_`A_B_C'' `controls_`i_j_k''/* by default: local var_x_in_reg_A `var_of_interest_A' - change if otherwise desired */
				local version `variant_of_reg'
				local if_condition `if_condition_`version''
				local options `reg_options_`version''
					

				/* estimates */
				pe `reg_command' `depvar' `var_x_in_reg' `if_condition' `options'
				pe estimates store `estlabel'`A_B_C'`variant_of_reg'
				estadd ysumm
				
				local auto_reg_list = "`auto_reg_list' `estlabel'`A_B_C'`variant_of_reg'"
				pe di "auto_reg_list = `auto_reg_list'"
				local auto_column_titles  "`auto_column_titles'  "spec. `A_B_C'`variant_of_reg'" "
				if `counter_rd' == 1 {
					local auto_groups `auto_groups' 1
					local auto_grouptitles `auto_grouptitles' "Group_`A_B_C'" 
					}
				if `counter_rd' != 1 {
					local auto_groups `auto_groups' 0
					}
				local counter_rd = `counter_rd' + 1
				}

			}

		**** objects in table:
		/* check out how many events, pages, observatoins and days are in the dataset  
			and provide that info as local */
			local time  flag_treated		/* add some dummy if it is a crosssection */
			local obs_id page_id		/* specify the adequate variable */
			local cluster_id start_page_name
			
			include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `auto_reg_list'"
			local mgroupsoption " `auto_grouptitles', pattern(`auto_groups') prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
			local columntitles " `auto_column_titles' "
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "Effect of the outgoing link's position in shocked page on attention on target: Dependent variable: `depvar', Var of Interest: `var_of_interest_`A_B_C''"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "22.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition "NOCH SPEZIELLERE BEMERKUNG "
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table shows a regression of link position on Attention /*
					*/ using alternative measures of link position. The first two columns show a count measure of /*
					*/ the group a link belongs to (1= 1-20\%, 2= 20-40\% etc.) and columns 3-6 are based on a /*
					*/ measure that measures the percentage of the text that lies before the link (scaled 0-100) /*
					*/ the first column of each group shows the regression without controls, the second includes /*
					*/ all control variables. /*
					*/ `notetext_addition'/*
					*/ ; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'_`depvar'_BCD.tex"
			local latexlabel `estlabel'`Cnt'`A_B_C' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

			pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N N_g r2_a ymean, fmt(0 0 2) labels("Observations" "Number of Groups" "Adj. R$^2$" "Mean of dep. var.")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(3) t(2) nogaps /*  nodepvars compress (nodepvars: no modeltitles, nogaps: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption') /*
				*/ mtitles(`columntitles') /*
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
			
			/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
				file write  `file_includer' "\begin{landscape}" 
				file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
				file write  `file_includer' "\end{landscape}" _n
				file write  `file_includer' _n
			
}		

local auto_reg_list = "" /* container leeren */
local auto_column_titles ""
local  auto_grouptitles ""
local auto_groups ""

*** Link Position and Activity
*******************************

	local estlabel "LnkPosAct"
	
	local reg_command regress
	
	local reg_options_1 /*", robust" */
	local reg_options_2 `reg_options_1' /* by default: local options_2 `options_1' - change if otherwise desired */
	** local reg_options_3 `options_1' /* by default: local options_2 `options_1' - change if otherwise desired */
	

foreach depvar in `main_depvar' {	
	local variables_interest A 
		/* A B C D */
	local controls_interest i j l
		/* i j k l */
		/* careful!, only 1 loop expected at the bottom, 
			=> make sure to deactivate the i_j_k loop if you wnat to iterate over vars of interest...
			=> for additional table per var of interest add options B C etc..... */
			
	foreach A_B_C in `variables_interest' { 
		foreach variant_of_reg in 0 1 2  { 
			/* default local variant_of_reg 1 2 */ 
			local counter_rd = 1
			foreach i_j_k in `controls_interest'{
			
				** specify controls, options and label.
				local var_x_in_reg `var_of_interest_`A_B_C'' `controls_`i_j_k''/* by default: local var_x_in_reg_A `var_of_interest_A' - change if otherwise desired */
				local version `variant_of_reg'
				local if_condition `if_condition_`version''
				local options `reg_options_`version''
					

				/* estimates */
				pe `reg_command' `depvar' `var_x_in_reg' `if_condition' `options'

				
				if "`version'" == "0" & "`depvar'" == "peak_clicks" {
				pe estimates store `estlabel'`i_j_k'`variant_of_reg'
				estadd ysumm					
				local auto_reg_list = "`auto_reg_list' `estlabel'`i_j_k'`variant_of_reg'"
					pe di "auto_reg_list = `auto_reg_list'"
					local auto_column_titles  "`auto_column_titles'  "spec. `i_j_k'`variant_of_reg'" "
					if `counter_rd' == 1 {
						local auto_groups `auto_groups' 1
						local auto_grouptitles `auto_grouptitles' "`depvar'" 
						}
					if `counter_rd' != 1 {
						local auto_groups `auto_groups' 0
						}
					local counter_rd = `counter_rd' + 1
					}
				
				
				if "`version'" == "1" & "`depvar'" == "flag_activity" {
				pe estimates store `estlabel'`i_j_k'`variant_of_reg'
				estadd ysumm					
				local auto_reg_list = "`auto_reg_list' `estlabel'`i_j_k'`variant_of_reg'"
					pe di "auto_reg_list = `auto_reg_list'"
					local auto_column_titles  "`auto_column_titles'  "spec. `i_j_k'`variant_of_reg'" "
					if `counter_rd' == 1 {
						local auto_groups `auto_groups' 1
						local auto_grouptitles `auto_grouptitles' "`depvar'" 
						}
					if `counter_rd' != 1 {
						local auto_groups `auto_groups' 0
						}
					local counter_rd = `counter_rd' + 1
					}
				

				if "`version'" == "2" & "`depvar'" == "abs_del_page_length" {
				pe estimates store `estlabel'`i_j_k'`variant_of_reg'
				estadd ysumm					
				local auto_reg_list = "`auto_reg_list' `estlabel'`i_j_k'`variant_of_reg'"
					pe di "auto_reg_list = `auto_reg_list'"
					local auto_column_titles  "`auto_column_titles'  "spec. `i_j_k'`variant_of_reg'" "
					if `counter_rd' == 1 {
						local auto_groups `auto_groups' 1
						local auto_grouptitles `auto_grouptitles' "`depvar'" 
						}
					if `counter_rd' != 1 {
						local auto_groups `auto_groups' 0
						}
					local counter_rd = `counter_rd' + 1
					}
				}

			}
		}
}
		**** objects in table:
		/* check out how many events, pages, observatoins and days are in the dataset  
			and provide that info as local */
			local time  flag_treated		/* add some dummy if it is a crosssection */
			local obs_id page_id		/* specify the adequate variable */
			local cluster_id start_page_name
			
			include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `auto_reg_list'"
			local mgroupsoption " `auto_grouptitles', pattern(`auto_groups') prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
			local columntitles " `auto_column_titles' "
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "Effect of the outgoing link's position in shocked page: Dependent variable: `depvar', Var of Interest: `var_of_interest_`A_B_C''"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "22.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition "NOCH SPEZIELLERE BEMERKUNG "
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table shows the relationship of a link's position in the outgoing text and /*
					*/ activity on the link's target. The dependent variable in the first three columns is an /*
					*/ variable indicating any editing activity on the page. The second three columns regresses the /*
					*/ length of the text change (additions and deletions) on the links position, conditional that any /*
					*/ changes were made. The first column in each group includes only dummies that indicate the Quintile of the link's position, /*
					*/ The second column includes article characteristics, the third also accounts for network characteristics. /*
					*/ Columns 4-6 do not include the 2 percent most substantial changes to account for outliers. /*
					*/ `notetext_addition'/*
					*/ ; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'_B.tex"
			local latexlabel `estlabel'`Cnt'`A_B_C' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

			pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N N_g r2_a ymean, fmt(0 0 2) labels("Observations" "Number of Groups" "Adj. R$^2$" "Mean of dep. var.")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(3) t(2) nogaps /*  nodepvars compress (nodepvars: no modeltitles, nogaps: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption') /*
				*/ mtitles(`columntitles') /*
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
			
			/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
				file write  `file_includer' "\begin{landscape}" 
				file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
				file write  `file_includer' "\end{landscape}" _n
				file write  `file_includer' _n
			
			
local auto_reg_list = "" /* container leeren */
local auto_column_titles ""
local auto_grouptitles ""
local auto_groups ""



local extratableregs1 PositionRegs1A1 PositionRegs1A4 PositionRegs2A1 PositionRegs2A4 PositionRegs3A1 PositionRegs3A4 PositionRegs4A1 PositionRegs4A4
esttab `extratableregs1',  star(* 0.10 ** 0.05 *** 0.01)

local extratableregs2  LnkPosActi1 LnkPosActj1 /*
	*/LnkPosActl1 LnkPosActi2  LnkPosActj2 LnkPosActl2  
esttab `extratableregs2'

local extratableregs3 PositionRegs1A1 PositionRegs1A5 PositionRegs2A1 PositionRegs2A5 /*
	*/ PositionRegs3A1 PositionRegs3A5 LnkPosActi2 LnkPosActl2
esttab `extratableregs3',  star(* 0.10 ** 0.05 *** 0.01)


local auto_column_titles ""
local auto_grouptitles "Attention" "Edits" "New Authors" "Absolute Length"
local auto_groups "1 0 1 0 1 0 1 0 "
local texoutputfile "  "

		**** objects in table:
		/* check out how many events, pages, observatoins and days are in the dataset  
			and provide that info as local */
			local time  flag_treated		/* add some dummy if it is a crosssection */
			local obs_id page_id		/* specify the adequate variable */
			local cluster_id start_page_name
			
			include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

		 
		* extend as required

			local regs_to_include " `extratableregs3'"
			local mgroupsoption " `auto_grouptitles', pattern(`auto_groups') prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
			local columntitles " `auto_column_titles' "
			local estusingfile "`table_slides_path'/`texoutput_file'"
			local titletext "Effect of the outgoing link's position in shocked page: Dependent variable: `depvar', Var of Interest: `var_of_interest_`A_B_C''"
			local scaling "50" /* in percent (0-100) */
			local widthlocal "22.5cm"  /* hochformat 16.5cm; querformat 24.5cm */
			local addnotetext1 "OLS-Regressions with robust standard errors."
			local addnotetext2 "Only treated articles (without umlaut). Dependent Variable: `outcome`x''."
			local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
			if "`A_B_C'" == "A" {
				local notetext_addition "NOCH SPEZIELLERE BEMERKUNG "
				}
			local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The Table shows the relationship of a link's position in the outgoing text and /*
					*/ activity on the link's target. The dependent variables are clicks (Columns 1-2), new revisions (Columns 3-4), new authors (Columns 5-6) and /*
					*/ length of the text change (additions and deletions) on the day of the neighbor's treatment (Columns 7-8). /*
					*/ For each dependent variable two columns are shown, which both regress the /*
					*/ dependent variable on the links position. /*
					*/ The first column in each group includes only dummies that indicate the Quintile of the link's position, /*
					*/ The second column includes article and network characteristics. /*
					*/ Columns (7) and (8) report the length of the text change (additions and deletions), conditional that more than a word was added or deleted.  /*
					*/ Two percent most substantial changes to account for outliers or potential vandalism. /*
					*/ `notetext_addition'/*
					*/ ; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

					
			local tableonlyfile "`table_stand_alone_path'`filename'_Overview.tex"
			local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
					N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/

			pe esttab `regs_to_include'/*
				*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
				*/ stats(N r2_a ymean, fmt(0 2 2) labels("Observations" "Adj. R$^2$" "Mean of dep. var.")) /* 
					in plugin_locals definieren
				*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
					in plugin_locals definieren
				*/  se(3)  b(3) t(2) nogaps /*  nodepvars compress (nodepvars: no modeltitles, nogaps: no \addlinespace)
					in plugin_locals definieren
				*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
					in plugin_locals definieren
				*/ nodepvars compress nonotes /*
				*/ mgroups(`mgroupsoption') nomtitles /* mtitles(`columntitles') 
				*/ title("`titletext' \label{tab:`latexlabel'}")   /*
				 addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
				*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
					*/ "\begin{tabular}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular}" /*
					*/ _ "\_" "\end{tabular}" "\end{tabular*}")  
					
			/* call file that includes tablenotes */
				include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
			
			
			/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
				file write  `file_includer' "\begin{landscape}" 
				file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
				file write  `file_includer' "\end{landscape}" _n
				file write  `file_includer' _n
				
	
	
pe file close `file_includer' 
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

cap log close
