/***********/ local filename = "wikidis_ana_PoD_shock_click_per_link" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
include "${PATH_EXTRA_PLUGIN}print_execute.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file analyses whether it is clicks per links rather than the peak that matter for the spillover.
desc_end ***/



*foreach linkdistance in L2 {
local linkdistance L1
local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_with_link_position_in_L0.dta"	



use "`startdata'", clear
* possibility of filtering
*************
	* keep if L0_peak_clicks > 650
	* keep if peak_clicks > 0 
	* keep if L0_peak_clicks < 15000 

* set up a tex-file for viewing all the outputs of this analysis
**********
local includer_name "${PATH_PAPER_VIEWASPDF}wikidis_click_per_link_caller.tex"
local file_includer and_table_caller
cap file close `includer_name' 
* cap file erase `includer_name' 
pe file open `file_includer'  using `includer_name', write replace

* DESCRIPTIVE FIGURES
**************

local storepath "${PATH_FIGURES}"
local graphname clicks_per_link

local variables_x L0_peak_clicks num_L0_links  /*put several if you wnat real iteration */
local variables_y peak_del_num_revisions peak_clicks  /*put several if you wnat real iteration */
local var_extra_category /*does not need to be filled */

local descriptive_plots_yes "yes" /* "yes" or "no" */
if "`descriptive_plots_yes'" == "yes" {

	foreach var_to_plot in `variables_y' {
		foreach var_x_axis in `variables_x' {
		/* choose order in which you want to iterate by excahnging y and x loop */
			local graph_file `storepath'`graphname'_`var_x_axis'
			local titletext "`var_to_plot' on `var_x_axis'"

			
			pe by `var_x_axis', sort: sum `var_to_plot'
			cap drop mean_`var_to_plot'
			pe by `var_x_axis' `var_extra_category': egen mean_`var_to_plot' = mean(`var_to_plot')
			
			* histogram
			pe hist `var_x_axis', discrete freq addlabels title(Distribution of `var_x_axis')
			local temp_graph_filename `graph_file'_hist.png
			graph export `temp_graph_filename', replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			
			
			sort `var_x_axis' `var_extra_category' start_page_name page_id

			* messy: all of it
			pe scatter `var_to_plot' `var_x_axis', title(`titletext' with freq.)  /* connect(direct)*/ mcolor(cranberry) msize(vtiny) /*
				*/ || lfit `var_to_plot' `var_x_axis'
			local temp_graph_filename `graph_file'_`var_to_plot'.png
			graph export `temp_graph_filename', replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			
			
			* Clean+Neat alternative
			preserve 
				pe collapse `var_to_plot', by (`var_x_axis' `var_extra_category')
				pe scatter `var_to_plot' `var_x_axis', title(`titletext') connect(direct) mcolor(cranberry) msize(large) /* jitter(20) */
				local temp_graph_filename `graph_file'_mean_`var_to_plot'.png
				graph export `temp_graph_filename', replace
				file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			restore
			
			* jitter

			pe scatter mean_`var_to_plot' `var_x_axis', title(`titletext' with freq.) /* connect(direct)*/ mcolor(cranberry) msize(vtiny)  jitter(10) 
			local temp_graph_filename `graph_file'_mean_`var_to_plot'_jitter.png
			graph export `temp_graph_filename', replace
			file write  `file_includer' _n "\includegraphics[scale=0.7]{`temp_graph_filename'}" _n 
			
			pe file write  `file_includer' _n "\clearpage" _n
		}
	}
}


** Regressions
*********************


* local texoutput_file "BLABLIBLUB.tex" /* file for collecting tables */
* local table_slides_path "${PATH_PAPER_MAIN}my_slides"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"
cap mkdir `table_stand_alone_path'


local estlabel "ClickPerLinkRegs"

local link_group_flags  flag_link_20_2 flag_link_20_3 flag_link_20_4 flag_link_20_5
* alternative: link_position_in_L0
local other_criteria num_repetitions_link  num_links_from_l1
	* max_link_position_rel has a surprisingly relevant effect, but I do not understand why  
* local heterogen_flags flag_stub flag_long flag_linked flag_super_l1 
local page_chars num_revisions num_authors page_length num_imagelinks 

local controls `link_group_flags' `other_criteria' `page_chars'

local depvarlist peak_clicks peak_del_num_revisions peak_del_num_authors
*foreach depvar in `depvarlist' {
*	foreach A_B_C in `variables_interest' {
		* local var_of_interest `var_of_interest_`A_B_C''
		local depvar peak_clicks
		
/* estimates */



pe  regress `depvar' L0_peak_clicks, robust
estimates store `estlabel'1
estadd ysumm

pe  regress `depvar' num_L0_links, robust
estimates store `estlabel'2
estadd ysumm

pe  regress `depvar' L0_clicks_per_link, robust
estimates store `estlabel'3
estadd ysumm

pe  regress `depvar' L0_peak_clicks `controls', robust
estimates store `estlabel'4
estadd ysumm


pe  regress `depvar' num_L0_links `controls', robust
estimates store `estlabel'5
estadd ysumm

pe regress `depvar' L0_clicks_per_link `controls', robust
estimates store `estlabel'6
estadd ysumm

pe regress `depvar'  `controls', robust
estimates store `estlabel'7
estadd ysumm

pe regress `depvar'  `link_group_flags', robust
estimates store `estlabel'8
estadd ysumm

pe regress `depvar'  `controls', robust
estimates store `estlabel'9
estadd ysumm

	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		local time time_var 		/* add some dummy if it is a crosssection */
		local obs_id page_id		/* specify the adequate variable */
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

 
* extend as required

	local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4  `estlabel'5 `estlabel'6 "
	local mgroupsoption " "pure correlations" "with controls", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "peak on L0 " " total L0 links " " Ratio L0 clicks/link "  "L0 peak " " total L0 links " " Ratio" "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Properties of shocked page and relationship to spillover. Dependent variable: `depvar'"
	local scaling "50" /* in percent (0-100) */
	local widthlocal "24.5cm"  /* hochformat 16.5cm; querforma t 24.5cm */
	local addnotetext1 "Pooled OLS-Regressions with robust standard errors."
	local addnotetext2 "Only x y z. Dependent Variable: `depvar'."
	local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the relationship between different properties of shocked page  /*
				*/ (the peak in viewership of the treated article contrasted with the number of outgoing links) /*
				*/ and the attention peak on the neighbors. Columns (1)-(3) shows the raw relationship and /*
				*/ Columns (4)-(6) include controls.  Specifications (1) and (4) give the relationship to the clicks on the shocked page;  /*
				*/ (2) and (5) show the association with the outgoing links.  /*
				*/ In Columns (3) and (6) I the variable of interest is the ratio of clicks per outgoing link on the shocked (L\_0) page.  /* 
				*/ The unit of observations is the outcome of a page i on day 0, the day of treatment of the treated (L\_0) pages.  /*
				*/ Standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

	local tableonlyfile "`table_stand_alone_path'`filename'_`depvar'.tex"
	local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/
	
	/*
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
		*/ nodepvars compress  se(3)  b(3) t(2) /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
	*/	
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N N_g r2_a, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /* 
			in plugin_locals definieren
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
			in plugin_locals definieren
		*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
			in plugin_locals definieren
		*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
			in plugin_locals definieren
		*/ nodepvars compress  nonotes /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
			*/ _ "\_" "\end{tabular}" "\end{tabular*}")  /*

		topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
	
	/* call file that includes tablenotes */
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	
	/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
		file write  `file_includer' "\begin{landscape}" _n
		file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
		file write  `file_includer' "\end{landscape}" _n
		file write  `file_includer' _n		
	



	* extend as required

	local regs_to_include "  `estlabel'8  `estlabel'7 `estlabel'4  `estlabel'5 `estlabel'6 "
	local mgroupsoption " "link order epicenter" "clickshock vs. number of links", pattern(1 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "raw correlation" " with controls "   "L0 peak " " total L0 links " " Ratio L0 clicks/link " "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Properties of shocked page and relationship to spillover. Dependent variable: `depvar'"
	local scaling "50" /* in percent (0-100) */
	local widthlocal "24.5cm"  /* hochformat 16.5cm; querforma t 24.5cm */
	local addnotetext1 "Pooled OLS-Regressions with robust standard errors."
	local addnotetext2 "Only x y z. Dependent Variable: `depvar'."
	local signs_to_erase_in_notes 13 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	local notetext \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows how a neighbor's peak in traffic is related to the link's position and to different /*
				*/ other properties of the shocked page /*
				*/ (the peak in viewership on the treated article contrasted with the number of outgoing links on the page.) /*
				*/ Columns (1)-(2) show the coefficients for link order. Columns (3)-(5) include the additional characteristics. /*
				*/ Specification (3) gives the relationship to the clicks on the shocked page;  /*
				*/ (4) shows the association with the outgoing links.  /*
				*/ In Columns (5) I add the ratio of clicks per outgoing link on the shocked (L\_0) page.  /* 
				*/ The unit of observations is the outcome of a page i on day 0, the day of treatment of the treated (L\_0) pages.  /*
				*/ Standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
				*/ no. of obs. = `num_obs_in_estimation'; /*
				*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

	local tableonlyfile "`table_stand_alone_path'`filename'_Heterogeneities.tex"
	local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/
	
	/*
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
		*/ nodepvars compress  se(3)  b(3) t(2) /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
	*/	
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ stats(N N_g r2_a, fmt(0 0 3) labels("Observations" "Number of Pages" "Adj. R$^2$")) /* 
			in plugin_locals definieren
		*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
			in plugin_locals definieren
		*/  se(3)  b(3) t(2) /*  nodepvars compress (nodepvars: no modeltitles, compress: no \addlinespace)
			in plugin_locals definieren
		*/ coeflabels(`position_labels' `varname_labels' `additional_features_labels' `heterogeneity_labels' )/* 
			in plugin_locals definieren
		*/ nodepvars compress  nonotes /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		addnote("`addnotetext1'" "`addnotetext2'")	  no more addnotetext, as this is to be overwriten by the notetext... 
		*/ substitute("\begin{tabular*}" " \fontsize{9}{11} \linespread{0.7} \selectfont \begin{tabular*}" /*
			*/ _ "\_" "\end{tabular}" "\end{tabular*}")  /*

		topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
	
	/* call file that includes tablenotes */
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do

		
pe file close `file_includer' 
est clear
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
