/***********/ local filename = "wikidis_rob_PoD_anniversary" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close


include "${PATH_EXTRA_PLUGIN}print_execute.do"

include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file performs a robustness check for when Today's featured article /*
	*/ was linked to an anniversary or a current event.
desc_end ***/


local file_includer table_includer
file open `file_includer' using "`path_output'/regtables_`DisPod'_`linkdistance'_includer.tex" , write replace


local path_output ${PATH_TABLES}
*foreach linkdistance in `link_distance_sets' {
foreach linkdistance in L0 L1 {
*local linkdistance L0
*local startdata = "${PATH_DISASTER_DATA}wikidis_`linkdistance'_pages.dta"	

	*use "`startdata'", clear

	local path "D:/workspace/AAA_wikipedia/wiki_disasters/"
	local using_path "trunk/wikidis_data/PoD_data/"
	local using_data "wikiPoD_samples\wikiPoD_`linkdistance'_post_cleaning.dta"


	use "`path'wikidis_raw_data_ignore\wikidis_anniversary_input.dta"


	drop if Wiki_Name == ""
	di "`path'`using_path'`using_data'"
	merge 1:m eve_time using "`path'`using_path'`using_data'"
	tab wiki_eve_name if _merge == 2
	tab Wiki_Name if _merge == 1
	tab Jubilaeum_etc
	count if Jubilaeum_etc == .
	
	
	rename _merge merger_anniversary
	replace Jubilaeum_etc = -99 if merger_anniversary < 3
	

	drop if merger_anniversary == 1
	*** delta variables, time_dummy_x_treatment, Diff in Diff Variables and time dummies

	local i_need_regressions_vars_yes = "yes"
	local i_need_delta_vars_yes = "yes"
	include "${PATH_PLUGIN}wikidis_plugin_addvars.do"
	* gen under_treatment = flag_treated & (placebo_state == 0)
	
	

		
	forvalues d1 = 1/7 {
		* drop if time_period`d1'
		}
		
	forvalues d2 = 23/29 {
		drop if time_period`d2'
		}
	

		
	local texoutput_file "robust_anniversary.tex" /* file for collecting tables */
	local table_slides_path "${PATH_PAPER_SLIDES}wikidis_auto_slides"
	local table_stand_alone_path "${PATH_REGRESULT_TABLES}"
	cap mkdir `table_stand_alone_path'
	local tab_desc_path "${PATH_DESCRIPTIVES_TABLES}"


	
	sort wiki_eve_name flag_treated
	egen clusters_fix_placebo = group(wiki_eve_name flag_treated)
	sum clusters_fix_placebo
	
	sort wiki_eve_name placebo_state
	egen clusters_fix_treatment = group(wiki_eve_name placebo_state)
	sum clusters_fix_treatment
	
	sort wiki_eve_name placebo_state
	egen clusters_all_reg = group(wiki_eve_name placebo_state flag_treated)
	
	
	local estlabel "`DisPod'DiDRobustXtregClust`linkdistance'" /* if in loop: pick sth that depands on iterable */

	
	/* estimates */

	pe xtreg clicks  `time_dummies'   `reg_crossterm_dummies' if flag_treated == 1 & Jubilaeum_etc == 0, fe robust cluster(clusters_fix_treatment) 
	estimates store `estlabel'1
	estadd ysumm

	pe xtreg clicks  `time_dummies'   `reg_crossterm_dummies' if flag_treated == 1 & Jubilaeum_etc == 1, fe robust cluster(clusters_fix_treatment) 
	estimates store `estlabel'2
	estadd ysumm

	pe xtreg clicks  `time_dummies'   `reg_crossterm_dummies' if flag_treated == 1 & Jubilaeum_etc == -99 , fe robust cluster(clusters_fix_treatment) 
	estimates store `estlabel'3
	estadd ysumm

	pe xtreg clicks  `time_dummies'   `reg_crossterm_dummies' if flag_treated == 1, fe robust cluster(clusters_fix_treatment) 
	estimates store `estlabel'4
	estadd ysumm


	
	**** objects in table:
		/* check out how many events, pages, observatoins and days are in the dataset  
			and provide that info as local */
			local time time_var 		/* add some dummy if it is a crosssection */
			local obs_id page_id		/* specify the adequate variable */
			local cluster_id start_page_name
			
			include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do  /* make sure the file is available */

	 
	* extend as required

		local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4"
		local mgroupsoption " "Group 1" "Group 2", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
		local columntitles A B C D
		local estusingfile "`table_slides_path'/`texoutput_file'"
		local titletext "Relationship of X and `depvar'. Dependent variable: `depvar'"
		local scaling "50" /* in percent (0-100) */
		local widthlocal "16.5cm"  /* hochformat 16.5cm; querforma t 24.5cm */
		local addnotetext1 "Pooled OLS-Regressions with robust standard errors."
		local addnotetext2 "Only x y z. Dependent Variable: `outcome`x''."
		local signs_to_erase_in_notes 7 /* note: make sure that a suitable \end{tabular} statement remains in the file 
													-- usually via the "substitute()" command in esttab or directly in the notetext */
		local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
					*/ \scriptsize{The table shows the results of the reduced form regressions to estimate the ITE.   /*
					*/ Columns (1)-(3) show the results for clicks and Columns (4-6) for new edits to the articles. /*
					*/ Specification (1) and (4) contrast treated and comparison group; /*
					*/ (2) and (5) show the comparison of treated articles with themselves but seven weeks earlier (placebo treatment). /*
					*/ In Columns (3) and (6) I juxtapose the treated subnetworks with all available comparison  groups at the same time. /*
					*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
					*/ The unit of observations is the outcome of a page i on day t. /* 
					*/ The time variable is normalized and runs from -14 to 14.;  /*
					*/ Only crossterms closer to treatment are shown, but all were included. /*
					*/ Reference group t-14 to t-5; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
					*/ no. of obs. = `num_obs_in_estimation'; /*
					*/ no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}	

		local tableonlyfile "`table_stand_alone_path'`filename'_`estlabel'.tex"
		local latexlabel `estlabel' /* don't change the name of local if you want the label in latex) !!
				N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/
		
		/* oder nach tni-style und mit APPEND 
		esttab `regs_to_include'/*
			*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
			*/ starlevels( * 0.10 ** 0.05 *** 0.01)  width(`widthlocal') /*
			*/ nodepvars compress  se(3)  b(3) t(2) /*
			*/ mtitles(`columntitles') /* nomtitles */ /*
			*/ title("`titletext' \label{tab:`latexlabel'}")   /*
			*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
			*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
			** export results to .tex file for presentation 
		*/
			
		esttab `regs_to_include'/*
			*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
			*/ `ymean_stats_display_option' /*
			*/ width(`widthlocal') nodepvars compress  /*
			*/ mgroups(`mgroupsoption') /*
			*/ mtitles(`columntitles') drop(_cons) /*
			*/ coeflabels(`varname_labels'  `cross_dummy_labels'  `cross_term_labels' )/*
			indicate(All dummies = `periods_to_drop')
			*/ indicate("Time Dummies = `periods_to_drop'")/*
			*/ title("`titletext' \label{tab:`latexlabel'}")   /*
			*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
			*/ substitute("\begin{tabular*}" " \fontsize{8}{10} \selectfont \begin{tabular*}" _ "\_" "\end{tabular}" "\end{tabular*}") 

			
		/* call file that includes tablenotes */
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
		
		/* optionally write into a file_includer file which helps to quickly look at the tables in a pdf */
		
		* file write  `file_includer' "\begin{landscape}" _n
		file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
		* file write  `file_includer' "\end{landscape}" _n
		file write  `file_includer' _n
		
drop _all
}	


** Rearrange to get the MainTable for the Robustness Check

** From clicking L0 to clicking L1 at the respective conditions; including when it is unknow if anniversary

	local regs_to_include " `DisPod'DiDRobustXtregClustL02 `DisPod'DiDRobustXtregClustL12 `DisPod'DiDRobustXtregClustL01 `DisPod'DiDRobustXtregClustL11  `DisPod'DiDRobustXtregClustL03 `DisPod'DiDRobustXtregClustL13"
	local mgroupsoption " "Anniversary" "No Anniversary" "unclear cases", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "Advertised (L0)" "Neighbors (L1)" "Advertised (L0)" "Neighbors (L1)" "Advertised (L0)" "Neighbors (L1)" "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Transmission of clicks from treated page to neighbors; Anniversaries."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "24.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the results of the reduced form regressions estimating the ATE and the ITE in clicks.   /*
				*/ Columns (1) and (2) show the results for Articles related to anniversaries /*
				*/ and Columns (3) and (4) for articles which are not related. /*
				*/ Specification (5) and (6) contrast advertisements, which could not be coded; /*
				*/ The left column in each group shows the clicks of advertised articles, the right columns shows the vaue on the neighbors. /*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms on and shortly after the day of treatment are shown individually, all others are shown as summarized in groups. /*
				*/ Reference group t-14 to t-8; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; \\    }}}
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_add_unclear_cases.tex"
	local latexlabel `DisPod'clickL0ToClickL1 /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	/*esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_dummy_labels'  `cross_term_labels' )/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate( "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{12}{14} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */

	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	

** From clicking L0 to clicking L1 at the respective conditions ++ adding the benchmark results;

	local regs_to_include " `DisPod'DiDRobustXtregClustL02 `DisPod'DiDRobustXtregClustL12  `DisPod'DiDRobustXtregClustL01 `DisPod'DiDRobustXtregClustL11 `DisPod'DiDRobustXtregClustL04 `DisPod'DiDRobustXtregClustL14  "
	local mgroupsoption "  "Anniversary" "No Anniversary" "All (Benchmark)", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "Advertised (L0)" "Neighbors (L1)" "Advertised (L0)" "Neighbors (L1)" "Advertised (L0)" "Neighbors (L1)" "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Transmission of clicks from treated page to neighbors; Anniversaries."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "24.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the results of the reduced form regressions estimating the ATE and the ITE in clicks.   /*
				*/ Columns (1) and (2) show the results for Articles related to anniversaries /*
				*/ and Columns (3) and (4) for articles which are not related. /*
				*/ Specification (5) and (6) add the baseline results for easier comparison; /*
				*/ The left column in each group shows the clicks of advertised articles, the right columns shows the vaue on the neighbors. /*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms on and shortly after the day of treatment are shown individually, all others are shown as summarized in groups. /*
				*/ Reference group t-14 to t-8; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; \\    }}}
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_overview.tex"
	local latexlabel `DisPod'clickL0ToClickL1 /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	/*esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_dummy_labels'  `cross_term_labels' )/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate( "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{12}{14} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */

	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	


** From clicking L0 to clicking L1 at the respective conditions;

	local regs_to_include " `DisPod'DiDRobustXtregClustL02 `DisPod'DiDRobustXtregClustL12 `DisPod'DiDRobustXtregClustL01 `DisPod'DiDRobustXtregClustL11  "
	local mgroupsoption "  "Anniversary" "No Anniversary" "All (Benchmark)", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "Advertised (L0)" "Neighbors (L1)" "Advertised (L0)" "Neighbors (L1)" "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Transmission of clicks from treated page to neighbors; Anniversaries."
	local scaling "20" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local signs_to_erase_in_notes 419
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
				*/ \scriptsize{The table shows the results of the reduced form regressions estimating the ATE and the ITE in clicks.   /*
				*/ Columns (1) and (2) show the results for Articles related to anniversaries /*
				*/ and Columns (3) and (4) for articles which are not related. /*
				*/ Specification (5) and (6) add the baseline results for easier comparison; /*
				*/ The left column in each group shows the clicks of advertised articles, the right columns shows the vaue on the neighbors. /*
				*/ Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. /*
				*/ The unit of observations is the outcome of a page i on day t. /* 
				*/ The time variable is normalized and runs from -14 to 14.;  /*
				*/ Only crossterms on and shortly after the day of treatment are shown individually, all others are shown as summarized in groups. /*
				*/ Reference group t-14 to t-8; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; \\    }}}
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_xtreg_clust_overview_4col.tex"
	local latexlabel `DisPod'clickL0ToClickL1 /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	/*esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels'  `cross_dummy_labels'  `cross_term_labels' )/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate( "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{12}{14} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */

	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
		
	
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
