/***********/ local filename = "wikidis_ana_augmented_PoD_L1L2" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file adds the number of clicks on the start page to the L1 and the L2 data
It also generates all the crossterms for estimation.
desc_end ***/


foreach linkdistance in L1 {
*
* `link_distance_sets' {
* linkdistance in L0 L1 L2

	local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_post_cleaning.dta"
	if "`linkdistance'" == "L1" {
		* local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_post_cleaning_without_umlaut.dta"
		}
	clear
	use "`startdata'", clear
	local viewtime 2000
	local longview 4000

*** delta variables, time_dummy_x_treatment, Diff in Diff Variables and time dummies

	local i_need_regressions_vars_yes = "yes"
	local i_need_delta_vars_yes = "yes"
	local i_need_spill_heterogeneity_vars  "yes"
	include "${PATH_PLUGIN}wikidis_plugin_addvars.do"

	
/*
local i_need_regressions_vars_yes = "no" 
local i_need_delta_vars_yes = "no"
	/* already created before */
local i_need_spill_heterogeneity_vars  "yes"
include "${PATH_PLUGIN}wikidis_plugin_addvars.do"
	* gen under_treatment = flag_treated & (placebo_state == 0)
*/

local figure_path = "${PATH_FIGURES}" /* note: for tables there are subfolders, but for figures, these are equal */

local path_paper = "${PATH_PAPER_MAIN}"
local figformat = "pdf"



*** 
* aggregate clicks on L1
sort placebo_state flag_treated time_var start_page_name

bys placebo_state flag_treated time_var start_page_name: egen summed_L1_clicks = total(clicks)
bys placebo_state flag_treated time_var start_page_name: egen summed_L1_revisions = total(del_num_revisions)
bys placebo_state flag_treated time_var start_page_name: gen obs_per_event = _N
bys placebo_state flag_treated time_var start_page_name: gen clicks_L0_weighted = clicks_L0/obs_per_event 

gen del_page_content = abs(del_page_length)
 
sum summed_L1_revisions

preserve 
collapse clicks_L0 (sum) total_L1_new_authors=del_num_authors total_L1_clicks=clicks (sum) total_L1_revisions=del_num_revisions /*
	*/	total_L1_page_length = del_page_length total_L1_content_change = del_page_content total_L1_new_refs = del_num_refs /*
	*/ total_L1_new_images = del_num_imagelinks total_L1_new_extlinks = del_num_extlinks  total_L1_new_wiklinks = del_SNwik_degree /*
	*/ , by(start_page_name placebo_state flag_treated time_var)
collapse clicks_L0 total_L1_clicks  total_L1_new_authors total_L1_revisions total_L1_new_refs total_L1_content_change /*
	*/ total_L1_page_length total_L1_new_images total_L1_new_extlinks total_L1_new_wiklinks, by(placebo_state flag_treated time_var)

cap label var total_L1_revisions 		"sum of revisions at all neighbors"
cap label var total_L1_new_authors 		"all new authors at L1"
cap label var total_L1_new_wiklinks 	"all new links at in L1"
cap label var total_L1_new_extlinks 	"all new links away from Wikipedia at L1"	
cap label var total_L1_page_length 		"total length increase at l1 (bytes)"	
cap label var total_L1_content_change	"sum of content edited at L1 (bytes)" 
cap label var total_L1_new_refs 		"all new references at neighbors"
cap label var total_L1_clicks			"sum of views at neighbors"

*** shorten the labels for all variable 
foreach var_to_label in time_var clicks_L0 total_L1_clicks  total_L1_new_authors total_L1_revisions total_L1_new_refs total_L1_content_change /*
	*/ total_L1_page_length total_L1_new_images total_L1_new_extlinks total_L1_new_wiklinks  {
	local cutlabel  : variable label `var_to_label'
	local shortlabel = substr("`cutlabel'",1 ,41)
	label var `var_to_label' "`shortlabel'"
	des `var_to_label'
	}
keep if time_var > -14
keep if time_var < 14	

twoway (line total_L1_clicks time_var if flag_treated == 1 & placebo_state == 0,  lwidth(thick))  || /*
	*/ (line total_L1_clicks time_var if flag_treated == 1 & placebo_state == 1,  lpattern(dash)) || /*
	*/ (line total_L1_clicks time_var if flag_treated == 0 & placebo_state == 0, lpattern(dot)) || /* 
	*/ (line clicks_L0 time_var if flag_treated == 1 & placebo_state == 0) /*
	*/ , xline(0) legend(label(1 "treated in treatment phase") label(2 "treated in placebo-test")/*
							*/ label(3 "not treated, treatment phase") label(4 "directly treated pages (L0)") col(2) symxsize(5))

		local combi_figure_name "total_clicks_over_time_L1vsL0_`DisPod'_4Lines"
		local panel_subtitle "" /* Hier kann ein subtitle stehen*/ 
		local truncation_note ""
		local titletext "`crit_a' over time"
							
		graph export `figure_path'`combi_figure_name'.`figformat', replace
		* * !epstopdf `figure_path'`combi_figure_name'.`figformat'
		
sleep `viewtime'

** figures with outcomes

	** figures with outcomes
	
	local a_values total_L1_revisions total_L1_new_authors total_L1_new_wiklinks total_L1_new_extlinks /*
				*/ total_L1_page_length total_L1_content_change total_L1_new_refs total_L1_clicks
	* `core_outcomes'
	
	local crit_b flag_treated
	local b_values 0 1
	local crit_c placebo_state
	local c_values 0 1
	
	* local crit_a clicks
	foreach crit_a in `a_values' {
		*mean variable:
		twoway /*
		*/ (line `crit_a' time_var if `crit_b' == 1 & `crit_c' == 0,  lwidth(thick) ) || /*
		*/ (line `crit_a' time_var if `crit_b' == 1 & `crit_c' == 1,  lpattern(dash))|| /*
		*/ (line `crit_a' time_var if `crit_b' == 0 & `crit_c' == 0    ) ||/*
				*/, xline(0) legend(label(1 "treated in treatment phase") label(2 "treated in placebo-test")/*
				*/ label(3 "not treated, treatment phase") label(4 "directly treated pages (L0)") col(2) symxsize(5))

		local combi_figure_name "`crit_a'_over_time_`linkdistance'_`DisPod'_3Lines"
		local panel_subtitle "" /* Hier kann ein subtitle stehen*/ 
		local truncation_note ""
		local titletext "`crit_a' over time"
							
		graph export `figure_path'`combi_figure_name'.`figformat', replace
		* !epstopdf `figure_path'`combi_figure_name'.`figformat'
		
		/* 
			file write `file_includer' "\begin{figure}" _n
			file write `file_includer' "\begin{center}" _n
			file write `file_includer' "\caption{Figure with means of `crit_a' over time: looking at all 4 groups in one plot}" _n
			file write `file_includer' "\includegraphics[scale=1]{`figure_path'/`combi_figure_name'.pdf}" _n
			file write `file_includer' "\end{center}" _n
			file write `file_includer' "\end{figure}" _n
			file write `file_includer' " " _n
		*/	
		sleep `longview'
}

restore

preserve
collapse summed_L1_clicks summed_L1_revisions clicks_L0, by(start_page_name placebo_state flag_treated time_var)

restore
	
local texoutput_file "wiki`DisPod'_explore_slides.tex"
local table_slides_path "${PATH_PAPER_SLIDES}"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"

cap mkdir `table_stand_alone_path'
cap erase "`table_slides_path'/`texoutput_file'"


		
	forvalues d1 = 1/7 {
		* drop if time_period`d1'
		}
		
	forvalues d2 = 23/29 {
		drop if time_period`d2'
		}
	

gen clicks_L0_x_day_14 = realtreat_x_period_14*clicks_L0
gen clicks_L0_x_day_15 = realtreat_x_period_15*clicks_L0
gen clicks_L0_x_day_16 = realtreat_x_period_16*clicks_L0
gen clicks_L0_x_day_17 = realtreat_x_period_17*clicks_L0

local clicks_x_day  clicks_L0_x_day_14 clicks_L0_x_day_15 clicks_L0_x_day_16 clicks_L0_x_day_17


*****
* look at stubs
*****




foreach period in 14 15 16 17 22 27 {
	gen flag_stub_x_day_`period' = realtreat_x_period_`period'*flag_stub
	}


local cross_stub_treat flag_stub_x_day_15 flag_stub_x_day_16  flag_stub_x_day_17  
	* flag_stub_x_day_14  flag_stub_x_day_22  flag_stub_x_day_27


foreach period in 15 16 17 {
	gen flag_linked_x_day_`period' = realtreat_x_period_`period'*flag_linked
	gen flag_long_x_day_`period' = realtreat_x_period_`period'*flag_long
}


*********************
* Estimation Table
*********************

local texoutput_file "wiki`DisPod'_explore_slides.tex"
local table_slides_path "${PATH_PAPER_SLIDES}"
local table_stand_alone_path "${PATH_REGRESULT_TABLES}"

cap mkdir `table_stand_alone_path'
* cap erase "`table_slides_path'/`texoutput_file'"


	di ""
	di ""
	di "*********************************"
	di "* DIFF IN DIFF with clustering + Robustness"
	di "*     and simple attempts at considering article characteristics."
	di "**********************************"
	di ""
	di ""

	
	local estlabel "`DisPod'AugmentDiDXtregClust"
	
	sort wiki_eve_name flag_treated
	egen clusters_fix_placebo = group(wiki_eve_name flag_treated)
	
	sort wiki_eve_name placebo_state
	egen clusters_fix_treatment = group(wiki_eve_name placebo_state)
	
	sort wiki_eve_name placebo_state
	egen clusters_all_reg = group(wiki_eve_name placebo_state flag_treated)

	local reg_crossterms `reg_crossterms' 
	* Include variables (or cross terms) that capture article properties at t = 0
	******************************************************************************
		
	if "`features'" == "simple" {

		xtreg clicks  `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ flag_long_x_day_15 flag_linked_x_day_15 /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'1
		

		xtreg del_num_revisions `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ flag_long_x_day_16 flag_linked_x_day_16 /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'2

		
		
		xtreg del_page_length `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ flag_long_x_day_16 flag_linked_x_day_16 /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'3

		
		
		
		}

	if "`features'" == "advanced" {

		foreach period in 13 14 15 16 17 {
			gen flag_super_l1_x_day_`period' = realtreat_x_period_`period'*flag_super_l1
			}
		
		local extra_flags /*
			*/ flag_super_l1_x_day_15 flag_super_l1_x_day_16 flag_super_l1_x_day_17 /*
			*/ flag_linked_x_day_15 flag_linked_x_day_16  flag_linked_x_day_17  /*
			*/ flag_long_x_day_15 flag_long_x_day_16 flag_long_x_day_17 
		
		xtreg clicks  `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ `extra_flags'/*
			*/ if placebo_state == 0 , fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'1


		xtreg del_num_revisions `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ `extra_flags' /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'2

		xtreg del_page_length `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ `extra_flags' /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'3
		
		xtreg del_num_authors `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ `extra_flags' /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'7
		
		xtreg del_num_refs `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ `extra_flags' /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'8
		
		xtreg del_num_imagelinks `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ `extra_flags' /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'9
		
		xtreg del_num_extlinks `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
			*/ `extra_flags' /*
			*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
		estadd ysumm
		estimates store `estlabel'10
		
		
		}
		

	* Analysis of Stubs alone
	*********************************************


	preserve
	keep if flag_stub_at_0
	xtreg clicks `time_dummies'  `reg_crossterm_dummies' /*
		*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estadd ysumm
	estimates store `estlabel'4


	xtreg del_num_revisions `time_dummies'  `reg_crossterm_dummies' /*
		*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estadd ysumm
	estimates store `estlabel'5

	
	xtreg del_page_length `time_dummies'  `reg_crossterm_dummies' /*
		*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estadd ysumm
	estimates store `estlabel'6

		
	xtreg del_num_authors `time_dummies'  `reg_crossterm_dummies' /*
		*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estadd ysumm
	estimates store `estlabel'11

	
	xtreg del_num_refs `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
		*/ `extra_flags' /*
		*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estadd ysumm
	estimates store `estlabel'12
	
	xtreg del_num_imagelinks `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
		*/ `extra_flags' /*
		*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estadd ysumm
	estimates store `estlabel'13
	
	xtreg del_num_extlinks `time_dummies'  `reg_crossterm_dummies' `cross_stub_treat' /*
		*/ `extra_flags' /*
		*/ if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estadd ysumm
	estimates store `estlabel'14

	
	
	restore

	* extend as required

	**** objects in table:
	/* check out how many events, pages, observatoins and days are in the dataset  
		and provide that info as local */
		local time time_var /* add some dummy if it is a crosssection */
		local obs_id page_id
		local cluster_id start_page_name
		
		include ${PATH_EXTRA_PLUGIN}esttab_plugin_compute_num_obs_for_table.do
		
		local example_file example	
	

	**** esttab
	local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4 `estlabel'5 `estlabel'6 "
	local mgroupsoption " "joint estimation" "short articles only", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "clicks" "revisions" "length" "clicks" "revisions" "length"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies, including article heterogeneity."
	local scaling "10" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust and clustered standard errors. "
	
	local signs_to_erase_in_notes 167 /* note: make sure that a suitable \end{tabular} statement remains in the file 
												-- usually via the "substitute()" command in esttab or directly in the notetext */
	
	local notetext \end{tabular*} \vspace*{0.3cm}\hspace{0.3cm}\parbox{`widthlocal'}{\scriptsize{{\scshape Notes:} /*
		*/ \scriptsize{The table shows the results of the reduced form regressions estimating the ITE for neighbors. Columns (1)-(3) show additional  /*
		*/ control variables that provide a deeper characterization of the articles to analyze if spillovers vary across these groups. 	/*
		*/ Columns (4-6) analyze the reduced sample that only contains articles that were shorter than 1500 bytes ('stubs').			/*
		*/ Specification (1) and (4) the results for clicks, (2) and (5) for new edits, and Columns (3) and (6) show added content. 	/*	
		*/ All estimations contrast the treated with both comparison groups (based on other featured articles and same articles but seven /*
		*/ weeks earlier (placebo treatment)). Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. 			/*
		*/ The unit of observations is the outcome of a page i on day t. The time variable is normalized and runs from -14 to 14.; 		/*
		*/ Only crossterms on and shortly after the day of treatment are shown individually, all others are shown as summarized in groups. /*
		*/ Reference group t-14 to t-8; standard errors in parentheses: *** p<0.01, ** p<0.05, * p<0.1; /*
		*/ no. of obs. = `num_obs_in_estimation'; no. of clusters = `clusters_in_estimation'; no. of articles = `distinct_obs_in_est'.\\    }}}
		
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_`linkdistance'_xtreg.tex"
	local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles  */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
	
	di "mamimu"
	
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels' `cross_term_core_labels' `additional_features_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate("Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		 addnote("`addnotetext1'" "`addnotetext2'")	  
		*/ substitute("\begin{tabular*}" " \fontsize{9}{10} \linespread{0.7} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
	
	
	include ${PATH_EXTRA_PLUGIN}esttab_plugin_add_nice_notes_to_table.do
	
	/* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n
	*/

	
***********************
* Extended analysis of all article, by article chars(for landscape)
***********************
	

	**** esttab
	local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'7 `estlabel'8 `estlabel'9 `estlabel'10"
	local mgroupsoption " "joint estimation" , pattern(1 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "clicks" "revisions" "length" "authors" "references" "images" "ext. links"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies, including article heterogeneity."
	local scaling "10" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust and clustered standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_`linkdistance'_extraregs.tex"
	local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	


	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
	
	di "mamimu2"
	
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels' `cross_term_labels' `additional_features_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate( "Time Dummies = `periods_to_drop'")/* "All cross = `crossterms_to_drop'"
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{8}{10} \linespread{0.7} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */	
	
***********************
* Extended analysis of stubs only (for landscape)
***********************
	

	**** esttab
	local regs_to_include " `estlabel'4 `estlabel'5 `estlabel'6  `estlabel'11 `estlabel'12 `estlabel'13 `estlabel'14"
	local mgroupsoption "  "short articles only", pattern(1 0 0 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(})   span erepeat(\cmidrule(lr){@span})" 
	local columntitles " "clicks" "revisions" "length" "authors" "references" "images" "ext. links"  "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of clicks/added revisions and time dummies, including article heterogeneity."
	local scaling "10" /* in percent (0-100) */
	local widthlocal "16.5cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust and clustered standard errors. "
	local addnotetext2 "Only crossterms closer to treatment are shown, but all were included. Reference group t-14 to t-5"
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_`linkdistance'_extrastubs.tex"
	local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
	
	di "mamimu3"
	
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/`ymean_stats_display_option' drop(_cons)  /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mgroups(`mgroupsoption') /*
		*/ mtitles(`columntitles') /*
		*/ coeflabels(`varname_labels' `cross_term_core_labels' `additional_features_labels')/*
		indicate(All dummies = `periods_to_drop')
		*/ indicate( "Time Dummies = `periods_to_drop'")/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		*/ substitute("\begin{tabular*}" " \fontsize{7}{9} \linespread{0.7} \selectfont \begin{tabular*}" _ "\_") 
		* topfile(${PATH_STATA_LOCAL}beg`scaling'table_mkm.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */	
	
}
exit

xtreg clicks  `time_dummies'  `reg_crossterms' `cross_stub_treat' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
estimates store `estlabel'1
estadd ysumm
	
xtreg del_num_revisions  `time_dummies'  `reg_crossterms' `cross_stub_treat' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
estimates store `estlabel'1
estadd ysumm


xtreg del_num_authors  `time_dummies'  `reg_crossterms' `cross_stub_treat' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
estimates store `estlabel'1
estadd ysumm
	
xtreg page_length time_var `time_dummies'  `reg_crossterms' `cross_stub_treat' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
estimates store `estlabel'1
estadd ysumm




exit
	xtreg clicks  `time_dummies'  `reg_crossterms'  if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm

	
	xtreg clicks  `time_dummies'  `reg_crossterms' `weekday_dummies' if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm

	xtreg clicks  `time_dummies'  `reg_crossterms' `weekday_dummies'  sum_clicks_on_neighbo if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm

	xtreg clicks  `time_dummies'  `reg_crossterms' `weekday_dummies' `clicks_x_day' /*
		*/  sum_clicks_on_neighbo if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm

	
	xtreg del_num_revisions `time_dummies'  `reg_crossterms' `weekday_dummies'  sum_clicks_on_neighbo if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm
	
		
	xtreg del_num_revisions `time_dummies'  `reg_crossterms' `weekday_dummies' `clicks_x_day' /*
		*/ sum_clicks_on_neighbo if placebo_state == 0, fe robust cluster(clusters_fix_placebo)
	estimates store `estlabel'1
	estadd ysumm

	
	
