/***********/ local filename = "wikidis_ana_regress" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file produces some first regressions (most importantly) of the L2 dataset
desc_end ***/


local path_output ${PATH_TABLES}
foreach linkdistance in L2 {

local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_post_cleaning.dta"


local file_includer table_includer
file open `file_includer' using "`path_output'/regtables_`DisPod'_`linkdistance'_includer.tex" , write replace

use "`startdata'", clear

local viewtime 7000

*** time dummies
	tab time_var,gen(time_period)

*** delta variables
	include "${PATH_PLUGIN}wikidis_plugin_addvars.do"
	* gen under_treatment = flag_treated & (placebo_state == 0)

*** Diff in Diff Variables
	gen post_shock = time_var > 0
	gen shock_x_real = post_shock*(placebo_state == 0)
	gen shock_x_treatment = post_shock*flag_treated
	

*** time_dummy_x_treatment
	gen flag_real_treatment = flag_treated&(placebo==0)&time_var >=0
	
	forvalues i = 1/29 {		
		gen realtreat_x_period_`i' = flag_real_treatment*time_period`i'
		}

		
	forvalues d1 = 1/7 {
		drop if time_period`d1'
		}
		
	forvalues d2 = 23/29 {
		drop if time_period`d2'
		}
	
local time_dummies = "time_period9 - time_period22  "

foreach depvar in clicks del_num_revisions {
	
	di ""
	di ""
	di "*********************************"
	di "* BY TREATMENT *"
	di "**********************************"
	di ""
	di ""




	regress `depvar' placebo_state post_shock shock_x_real if flag_treated == 0, robust
	regress `depvar' placebo_state post_shock shock_x_real if flag_treated == 1, robust

	sleep `viewtime'

	di ""
	di ""
	di "*********************************"
	di "* BY PLACEBO *"
	di "**********************************"
	di ""
	di ""

	regress `depvar' flag_treated post_shock shock_x_treatment if placebo_state == 1, robust
	regress `depvar' flag_treated post_shock shock_x_treatment if placebo_state == 0, robust



	di ""
	di ""
	di "*********************************"
	di "* BY TREATMENT *"
	di "**********************************"
	di ""
	di ""


	regress `depvar' placebo_state `time_dummies' if flag_treated == 0, robust
	regress `depvar' placebo_state `time_dummies' if flag_treated == 1, robust

	sleep `viewtime'

	di ""
	di ""
	di "*********************************"
	di "* BY PLACEBO *"
	di "**********************************"
	di ""
	di ""

	regress `depvar' flag_treated `time_dummies' if placebo_state == 1, robust
	regress `depvar' flag_treated `time_dummies' if placebo_state == 0, robust


	di ""
	di ""
	di "*********************************"
	di "**** XTREG ****"
	di "**********************************"
	di ""
	di ""
	di ""
	di ""
	di "*********************************"
	di "* BY TREATMENT *"
	di "**********************************"
	di ""
	di ""


	xtreg `depvar'  `time_dummies' if flag_treated == 0, fe robust
	xtreg `depvar' `time_dummies' if flag_treated == 1, fe robust

	sleep `viewtime'

	di ""
	di ""
	di "*********************************"
	di "* BY PLACEBO *"
	di "**********************************"
	di ""
	di ""

	xtreg `depvar'  `time_dummies' if placebo_state == 1, fe robust
	xtreg `depvar' `time_dummies' if placebo_state == 0, fe robust


	di ""
	di ""
	di "*************************************************"
	di "* LOOK AT ALL FOUR GROUPS SEPERATELY *"
	di "*************************************************"
	di ""
	di ""

	local texoutput_file "wikidis_explore_slides.tex"
	local table_slides_path "${PATH_PAPER_SLIDES}"
	local table_stand_alone_path "${PATH_REGRESULT_TABLES}"
	cap mkdir `table_stand_alone_path'

	local estlabel "`DisPod'EveStudyXtreg"

/* estimates */

	di "** not treated and placebo (completely irrelevant)"
	xtreg `depvar' flag_treated placebo_state  `time_dummies' if flag_treated == 0 & placebo_state == 1, fe robust
	estimates store `estlabel'1

	di "** not treated, at the time of event (control)"
	xtreg `depvar' flag_treated placebo_state `time_dummies' if flag_treated == 0 & placebo_state == 0, fe robust
	estimates store `estlabel'2

	di "** treated articles a year earlier (placebo)"
	xtreg `depvar' flag_treated placebo_state `time_dummies' if flag_treated == 1 & placebo_state == 1, fe robust
	estimates store `estlabel'3

	di "** treated articles at the time of event (treatment)"
	xtreg `depvar' flag_treated placebo_state `time_dummies' if flag_treated == 1 & placebo_state == 0, fe robust
	estimates store `estlabel'4


	* extend as required

	local regs_to_include " `estlabel'1 `estlabel'2 `estlabel'3 `estlabel'4"
	local columntitles " "control+placebo" "control" "placebo" "real treatment" "
	local estusingfile "`table_slides_path'/`texoutput_file'"
	local titletext "Relationship of `depvar' and time dummies."
	local scaling "50" /* in percent (0-100) */
	local widthlocal "16cm"
	local addnotetext1 "Fixed Effects Panel-Regressions with heteroscedasticity robust standard errors. "
	local addnotetext2 "Only dummies closer to treatment are shown, but all were included. Dependent Variable: `depvar'."
	local tableonlyfile "`table_stand_alone_path'`filename'_`DisPod'_event_`depvar'.tex"
	local latexlabel `estlabel' /* don't change the name of local unless you want special label in latex) !!
			N.B.: most of the times the same sometimes not (e.g. when several customizations of tables needed)*/	

	local periods_to_drop time_period2  time_period4 time_period5 time_period6 time_period7 time_period8 time_period9 time_period10  time_period11/*
		*/ time_period29 time_period28 time_period27 time_period26 time_period25 time_period24 time_period23 time_period22 time_period21 time_period20 
	
	/* oder nach tni-style und mit APPEND */
	esttab `regs_to_include'/*
		*/ using `estusingfile', append booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' width(`widthlocal') nodepvars compress  /*
		*/ mtitles(`columntitles') /* nomtitles */ /*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	 /*
		*/ topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation 
		
	esttab `regs_to_include'/*
		*/ using `tableonlyfile', replace booktabs `control_spec' /* ar2 */ /*
		*/ `stats_display_option' /*
		*/ width(`widthlocal') nodepvars compress  /*
		*/ mtitles(`columntitles')/*
		*/ coeflabels(`varname_labels' `time_dummy_labels')/*
		*/ indicate(All dummies = `periods_to_drop') drop(o.*)/*
		*/ title("`titletext' \label{tab:`latexlabel'}")   /*
		*/ addnote("`addnotetext1'" "`addnotetext2'")	  /*
		topfile(${PATH_STATA_LOCAL}beg`scaling'_tni.tex) bottomfile(${PATH_STATA_LOCAL}end_tni.tex) 
		** export results to .tex file for presentation */
	
	* file write  `file_includer' "\begin{landscape}" _n
	file write  `file_includer' _n "\input{`tableonlyfile'}" _n 
	* file write  `file_includer' "\end{landscape}" _n
	file write  `file_includer' _n
	
	}
	
	
file close `file_includer'

}
log close
