/***********/ local filename = "wikidis_cr_start_data" /******************/



clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file insheets the new data and filters 
	start_pages and l1_link and produces a simple first start dataset
desc_end ***/


/* prepare time_invariant dataset for start pages and L2 data */


use "${PATH_INSHEET_DSH}wiki`DisPod'_time_invariant_insheet.dta", clear
set seed 47110815
gen sampler = runiform()

sort page_id
egen page_groups = group(page_id)
** counting the  number of non-missing observations in each group
	* by page_groups, sort: egen freq_page_appears = count(page_id)
	by page_groups, sort: egen freq_page_appears = count(page_first_revision_time)
	/* counting page_first_revision_time is equivalent to counting page ids */
	
tab freq_page_appears
tab link_distance_from_startpage
`browse' if link_distance_from_startpage == 0
tab flag_treated if link_distance_from_startpage == 0

/* run more checks to make sure each page appears only once */

duplicates tag page_id, gen(double_page_id)
duplicates tag page_id eve_time, gen(double_page_id_eve_time)

tab double_page_id double_page_id_eve_time

${mkm_debug_reduction}

save "${PATH_INSHEET_LINK_FLAVOURS}wiki`DisPod'_time_invariant.dta", replace


** now merge the time variant and the time invariant data.
	/* N.B.: since the time invaraint data contains only L2 keeping only if _merge == 3 ensures a "pure" L2 dataset */
	



	
	use "${PATH_INSHEET_DSH}wiki`DisPod'_time_variant_insheet.dta" , clear
	merge m:1 (page_id /*flag_treated*/) using "${PATH_INSHEET_LINK_FLAVOURS}wiki`DisPod'_time_invariant.dta"
	tab _merge
	keep if _merge == 3
	rename _merge merger_invariant
	order page_id day eve_id start_page_name eve_time
	save "${PATH_LAST_FULL_L2_DATA}wiki`DisPod'_pages_full.dta", replace
	
	
	generate DATAWAVE_idx = "${DATAWAVE}"
	
	
	/* fix a time_zero which is the (for placebo, imagined) point when the disaster hit */
	if "`DisPod'" == "PoD"  & "${DATAWAVE}" <= "4" {
		scalar time_normalization_secs = 7*7*86400
		}

	if "`DisPod'" == "dis" & "${DATAWAVE}" < "4"{
		* scalar time_normalization_secs = 49*86400
		scalar time_normalization_secs = 365*86400
		}
	
	if "${DATAWAVE}" >= "5" {
		scalar time_normalization_secs = 9*7*86400
		}
		
	gen time_zero = eve_time - placebo_state*time_normalization_secs

	** overrule time_zero for ti10d20-merger:
	if "`DisPod'" == "PoD"  &  "${DATAWAVE}" == "Ti10D20"{
		drop time_zero
		gen time_zero = .
		scalar time_norm_sec_Ti10 = 7*7*86400
		scalar time_norm_sec_D20 = 9*7*86400
		replace time_zero = eve_time - placebo_state*time_norm_sec_Ti10 if (wave_idx == "Ti10")
		replace time_zero = eve_time - placebo_state*time_norm_sec_D20 if (wave_idx == "D20")
		}
		
	** overrule time_zero for ti10d20-merger:
	if "`DisPod'" == "PoD"  &  "${DATAWAVE}" == "Ti10D20D05"{
		drop time_zero
		gen time_zero = .
		scalar time_norm_sec_Ti10 = 7*7*86400
		scalar time_norm_sec_D20 = 9*7*86400
		scalar time_norm_sec_D05 = 9*7*86400
		
		replace time_zero = eve_time - placebo_state*time_norm_sec_Ti10 if (wave_idx == "Ti10")
		replace time_zero = eve_time - placebo_state*time_norm_sec_D20 if (wave_idx == "D20")
		replace time_zero = eve_time - placebo_state*time_norm_sec_D05 if (wave_idx == "D05")
		}

	** generate a normalized unix time stamp (basis for the  human readable one)
	gen unix_time_var = day - time_zero
	
	/* generate time_var such that 0 = first observation *AFTER shock */
		gen time_var = .
		
		replace time_var = int(unix_time_var/86400) if unix_time_var < 0 
		replace time_var = int(unix_time_var/86400) if unix_time_var >= 0 
	
	* drop if time_var < -14
	* drop if time_var > 14
	order page_id time_var unix_time_var eve_id start_page_name  day eve_time


	/* rename variables to be in sync with paper 1 */

		* rename v1 day
		* rename v2 page_id
		rename outward_links 					SNwik_out_degree
		rename click_number						clicks
		rename revision_number 					num_revisions  /* is this accurate */
		rename author_number					num_authors
		rename page_lengths 					page_length
		rename rev_stat_image_link_number 		num_imagelinks
		rename rev_stat_is_explanation  		is_explanation 
		rename rev_stat_is_redirect 			is_redirect
		rename rev_stat_literature_number 		has_lit
		rename rev_stat_reference_number 		num_refs
		rename rev_stat_external_links 			num_extlinks
		
		rename indegree 						SNwik_degree
		* rename global_closeness_in				SNwik_closeness
		* rename global_eigenvector				SNwik_eigenvector
		* rename global_node_number 				SNwik_node_number

		gen zzna_SNwik_between_ggi = .

		/* leave eco_local and soc_local untouched and prepare SNcat - variables 
		gen SNcat_degree	= .
		gen SNcat_between	= .
		gen SNcat_closeness 	= .
		gen SNcat_node_number	= .
		gen SNcat_out_closeness  = .
		*/

		local num_vars = "num_revisions num_imagelinks num_authors num_extlinks num_refs"
		local page_vars = "page_length  is_explanation is_redirect  out_degree "
				

	/* COMPRESS AND MVDECODE */ 
		
		compress
		mvdecode _all, mv(-99)
		compress
		include "${PATH_PLUGIN}wikidis_plugin_labels"
		
	/* BALANCING */
		sort placebo_state page_id
		
		egen mkm_id = group(placebo_state page_id)
			/* note that every observation has a placebo duplicate, that's why page_id time_var 
				will not uniquely identify an observation => mkm_id, will) */
		sort mkm_id time_var
		by mkm_id: egen minday = min(day)
		drop if minday < page_first_revision_time & link_distance_from_startpage > 0
	
	
	/* xtset */
		tab time_var
		xtset mkm_id time_var
		xtdes
	
	
	/* save */
	save "${PATH_DISASTER_DATA}wiki`DisPod'_all_pages.dta", replace
	`browse'


	
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
