/***********/ local filename = "wikidis_cr_shock_crosssection_PoD" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close


include "${PATH_EXTRA_PLUGIN}print_execute.do"

include "${PATH_PLUGIN}wikidis_plugin_locals.do"
log using "${PATH_LOGS}/`filename'.log", replace

**** Short description of do-file:
/* This do file 
generates crosssection-data files, that summarize 
	i.) the peak, (abs. value (gross) and peak net of average (peak)
	ii.) the overall effect of the event 
	and iii.) allow relating it to the size of the original shock...
* NOTA BENE: for disasters you need a file of it's own. THERE:
	* do it only for L2
	* collapse L1_dis to one observation/set of neighbors (take totals) as reference for "initial shock"
desc_end ***/

* check L0 dataset
*****************************
use "${PATH_DISASTER_SAMPLES}wiki`DisPod'_L0_post_cleaning.dta"
sum


clear

foreach linkdistance in L0 L1 {
* local linkdistance L0		 /* L0 L1 L2 */
	* make sure file only adresses PoD - treatment (dis is different)
	local DisPod = "PoD"
	
	local startdata = "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_post_cleaning.dta"


*** open dataset
use "`startdata'", clear

local bylist `panel_key' /* wikidis_plugin */
local sortlist `unique_key' 
sort `sortlist'


*** add delta vars special articles falg for analysis fo heterogeneity

	local i_need_delta_vars_yes = "yes"
	local i_need_long_term_deltas_yes = "yes"
	local i_need_spill_heterogeneity_vars  "yes"
	include "${PATH_PLUGIN}wikidis_plugin_addvars.do"

*** new variables that contain gross-peak
************************++
	/***
	for each var of interest: generate a dummy flags days 0 to 4
		Evaluate the highest value that occured up to 4 days after treatment.
		=> that way I can account for a potential lag from clicks, to edits to length
			(or measurement difference)
	*/
	
	gen abs_del_page_length = abs(del_page_length)
	gen flag_3_days_into_treat = time_var > -1 & time_var < 5
	local varlist del_num_revisions del_num_authors clicks abs_del_page_length
	foreach var in `varlist' {
		gen `var'_peak_help = `var' * flag_3_days_into_treat
		sort `sortlist'
		pe by `bylist': egen gross_peak_`var' = max(`var'_peak_help)
		drop `var'_peak_help
		local gross_peak_vars `gross_peak_vars' gross_peak_`var'
	}	

*** new vars with net peak
		** peak net of the page's average (excl. peak at treatment) (but average before and after)

	sum time_var
	scalar num_days = r(max)- r(min) + 1
	scalar num_days_before = 0 - r(min) 
	
	** note: the real number has to account for day 0
	di "number of days is: " num_days "  num_days_before is:  " num_days_before
	
	gen flag_before = time_var >= r(min) & time_var < 0
	gen flag_week_before = time_var >= -7 & time_var < 0
	gen flag_week_after = time_var > 0 & time_var < 7
	gen flag_after = time_var > 0 & time_var < r(max)
	
	local net_peaks
	local net_vars 
	foreach var in `varlist' {
		by `bylist': egen agg_`var'= total(`var')
		pe gen sum_net_peak_`var' = agg_`var' - gross_peak_`var'
		pe gen avg_net_peak_`var' = sum_net_peak_`var'/(num_days-1)
		pe gen net_peak_`var'_1 = gross_peak_`var' - avg_net_peak_`var' 
		local net_peaks `net_peaks' net_peak_`var'_1
		local net_vars `net_vars' avg_net_peak_`var'
		* checks: order `var' gross_peak_`var' agg_`var' avg_net_peak_`var' net_peak_`var' agg_`var' sum_net_peak_`var'   
		drop agg_`var' sum_net_peak_`var'
		}

***** peak net of the page's average before treatment.
**********************
	local net_before_vars ""
	local net_peaks_2 ""
	foreach var in `varlist' {
		gen `var'_before_hlp = `var' * flag_before						/* value is positive if before shock */
		pe by `bylist': egen agg_before_`var' = total(`var'_before_hlp) /* sum values before shock */
		pe gen avg_before_`var' = agg_before_`var'/(num_days_before)	/* comute average */
		pe gen net_peak_`var'_2 = gross_peak_`var' - avg_before_`var' 		/* subtract avg. from  peak */
		local net_peaks_2 `net_peaks_2' net_peak_`var'_2				/* store names in local */
		local net_before_vars `net_before_vars' avg_before_`var' 
		drop `var'_before_hlp agg_before_`var' 
		}

** long term deltas

	sort mkm_id time_var
	xtset mkm_id time_var
	
	
	
	local init 1
	local step 7
	local stop 22
	
	local week_diffs ""
	forvalues val = `init'(`step')`stop' {
		di "val is `val'"
		local start = `val' 
		* local stop = `val' + `step'
		local stop = `val' + 7
		
		di "by mkm_id: gen del_`start'_`stop'_page_length 	= 	page_length[_`stop'] - page_length[_`start']"
		
		by mkm_id: gen del_`start'_`stop'_page_length 	= 	abs(page_length[`stop'] - page_length[`start'])
		by mkm_id: gen del_`start'_`stop'_num_authors 	= 	abs(num_authors[`stop'] - num_authors[`start'])
		by mkm_id: gen del_`start'_`stop'_num_revisions = 	abs(num_revisions[`stop'] - num_revisions[`start'])
		by mkm_id: gen del_`start'_`stop'_num_refs 		= 	abs(num_refs[`stop'] - num_refs[`start'])
		by mkm_id: gen del_`start'_`stop'_num_imagelinks = 	abs(num_imagelinks[`stop'] - num_imagelinks[`start'])
		by mkm_id: gen del_`start'_`stop'_num_extlinks 	= 	abs(num_extlinks[`stop'] - num_extlinks[`start'])
		by mkm_id: gen del_`start'_`stop'_SNwik_degree 	= 	abs(SNwik_degree[`stop'] - SNwik_degree[`start'])
		foreach var in num_revisions `outcomes_long_term' {
			local week_diffs `week_diffs' del_`start'_`stop'_`var'
			}
		}

	
	local week_diff_diffs ""
	foreach var in `outcomes_long_term' {
		gen week_diff_pre_`var' = del_8_15_`var' - del_1_8_`var'
		gen week_diff_after_`var' = del_15_22_`var' - del_1_8_`var'
		local week_diff_diffs `week_diff_diffs' week_diff_pre_`var' week_diff_after_`var'
		*gen week_diff_long_after_`var' = del_15_22_`var' - del_1_8_`var'
		}
	
	
		
*** other variables
****************************+
	
*** new variables that contain diff-14to-1 and diff0to13
	local before_after_vars ""
	foreach var in `varlist' {
		gen `var'_before_help = `var' * flag_week_before
		sort `sortlist'
		pe by `bylist': egen agg_`var'_before = total(`var'_before_help)
		gen `var'_after_help = `var' * flag_week_after
		by `bylist': egen agg_`var'_after = total(`var'_after_help)
		drop `var'_after_help `var'_before_help
		local before_after_vars `before_after_vars'  agg_`var'_after agg_`var'_before
	}


*** introduce a few sanity checks for comparison
	/*** compute the 
		.) variable's average (including the peak)
		.) the average net of the peak.
	***/
	sort `sortlist'
	
	local sanity_vars ""
	foreach var in `varlist' {
		** just the average
		by `bylist': egen avg_`var'= mean(`var')
		local sanity_vars `sanity_vars' avg_`var'
		}
	

	* checks: 	
	* order flag_week_before flag_week_after agg* clicks flag_3_days_into_treat peak* 
	* browse	
	
	
*** select the peak_var to be used in subsequent estimations
*******************

	local peak_vars ""
	local varlist del_num_revisions del_num_authors clicks
	foreach var in `varlist' {
		gen peak_`var' = net_peak_`var'_2 /* peaks net of average before treatment */
		/* for choics: 
		net_peak_1 		=> peak net of the average (before and after, but excl. treatment)
		net_peak_2 		=> just the 
		and gross_peak 	=> just the absolute value
			*/
		local peak_vars `peak_vars' peak_`var'
		}

	local del_var_list del_num_authors del_num_revisions del_page_length del_num_extlinks del_num_refs del_num_imagelinks
	local all_peak_vars `net_peaks_2' `net_peaks' `gross_peak_vars'
	local augmented_list  num_links_from_l1 SNwik_degree flag_stub flag_long flag_linked flag_super_l1
	local keeplist day_of_month  `peak_vars' `before_after_vars' `week_diffs'  `week_diff_diffs'	 `sanity_vars' `core_outcomes' `unique_key'  eve_id eve_time mkm_id /* time_period2 */
	cap sort `keeplist' 
		if _rc local keeplist `peak_vars' `before_after_vars' `sanity_vars' `core_outcomes' `unique_key'  eve_id eve_time mkm_id  /* time_period2 */
	
	if "`linkdistance'" != "L0" {
		local keeplist `keeplist' `augmented_list' `del_var_list' 
		}
	display "`peak_vars' `before_after_vars' `sanity_vars' `core_outcomes' `unique_key'"
	keep `keeplist'
	order  `peak_vars' `before_after_vars' `sanity_vars' eve_id 
	keep if time_var == 1
	save "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_peaks.dta", replace
	
	di "`week_diffs'"
	di "`week_diff_diffs'"

	local event_cluster_id placebo_state day_of_month flag_treated start_page_name  
	cap sort `event_cluster_id'
		if _rc local event_cluster_id placebo_state flag_treated start_page_name  

	sort `event_cluster_id'
	if "`linkdistance'" != "L0" {
		local keeplist `keeplist' `augmented_list' `del_var_list' 
		pe collapse `core_outcomes' /*
			*/ (first) page_id time_var `augmented_list'/*
			*/ (sum) `week_diffs'  `week_diff_diffs' `peak_vars' `before_after_vars'  /*
			*/ /* try with means rather than sums
			*/ , by (`event_cluster_id')
			save "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_by_event.dta", replace

		}
	clear
}

*** merge L1_peak with L0_peak dataset to get original peak (for disasters more involves (avg(L1-peak) is required) 


* foreach linkdistance in L1 {
local linkdistance L1		 /* L1 L2 */


use "${PATH_DISASTER_SAMPLES}wiki`DisPod'_L0_peaks.dta", replace
cap sort `event_cluster_id'
	if _rc local event_cluster_id placebo_state flag_treated start_page_name  

rename peak_clicks 			L0_peak_clicks

gen L0_avg_clicks = avg_clicks - L0_peak_clicks/29
rename agg_clicks_before	L0_agg_clicks_before
rename agg_clicks_after		L0_agg_clicks_after
	/* more? */
keep L0_peak_clicks L0_avg_clicks L0_agg_clicks_before /*
	*/ L0_agg_clicks_after `event_cluster_id'


merge 1:m `event_cluster_id' using "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_peaks.dta"
rename _merge merger_peaks


sort placebo_state flag_treated start_page_name
egen event_cluster_id = group(placebo_state flag_treated start_page_name)


* drop outliers 
*****************
local outlier_vars peak_clicks peak_del_num_authors peak_del_num_revisions
foreach var in `outlier_vars' {
	centile `var' if flag_treated & placebo_state == 0, centile(99 98 99.5)
	di int(r(c_3))
	drop if `var' > int(r(c_3))
	}

** check regs
************************

* foreach
local var clicks
gen L0_peak_clicks_sq = L0_peak_clicks*L0_peak_clicks
reg peak_`var' L0_peak_clicks  , cluster(event_cluster_id)
** any furtehr analysis in seperate file


* save the data
*****************
save "${PATH_DISASTER_SAMPLES}wiki`DisPod'_`linkdistance'_with_L0_peaks.dta", replace


	
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
