/***********/ local filename = "template_standard_figures" /******************/

clear all
* version 10.1
${memory_use}
${processors_use}
set more off
cap log close



**** Short description of do-file:
/* This do file contains a bunch of figures which are frequently needed
desc_end ***/


include "${PATH_LIBRARY}stata_local/wiki_plugin_locals.do"

local path_output = "${ADEQUATE_PATH_OUT}"
local path_paper = "${PATH_PAPER_MAIN}"
local figformat = "eps"
	

local des_data_file "path_to_data/data_file.dta"	
use "`des_data_file'", clear


**************************
* Defining the variables this file is about
**************************

local time_var 				/* the_time_variable_if_any */
local core_outcomes 		/* list_of_interesting_dependent_variables */
local core_indep_vars 		/* main_rhs_variables */

*** shorten the labels for all variable 
foreach var_to_label in `time_var'   `core_outcomes' `core_indep_vars' {
	local cutlabel  : variable label `var_to_label'
	local shortlabel = substr("`cutlabel'",1 ,31)
	label var `var_to_label' "`shortlabel'"
	des `var_to_label'
	}
	


****************************************
*** scatter plots of the means over time	
*********************************************

file open graphwriter using "`path_output'/graphs_to_include.tex" , write replace
* file write graphwriter "Hello graphs" _n 



preserve

	collapse `mean_outcomes' `mean_SNA_variables' `outcomes' `SNA_variables' `further_SN_vars' `min_SNA_vars' `max_SNA_vars' `min_outcomes' `max_outcomes' /*
		*/ `p90_outcomes' `p90_SNA_vars' `p10_outcomes' `p10_SNA_vars', by(time_var)
   
	
	*** shorten the labels for all variable 
		foreach var_to_label in `mean_outcomes' `mean_SNA_variables' `min_SNA_vars' `min_outcomes' `p90_outcomes' `p10_outcomes' `p90_SNA_vars' `p10_SNA_vars'{
			local cutlabel  : variable label `var_to_label'
			local shortlabel = substr("`cutlabel'",8 ,28)
			label var `var_to_label' "`shortlabel'"
			des `var_to_label'
			}
	
	foreach out_var in  `outcomes'  {
		* by time_var, sort: egen mean_`out_var'= mean(`out_var')
		twoway (line  mean_`out_var' time_var) (line  p10_`out_var' time_var) /*
		*/ (line  p90_`out_var' time_var), saving(`figure_path'/wiki_3lines_`out_var'.gph, replace) /*
		*/ legend(rows(1)) ylabel(#4, alternate)
		graph export  "`figure_path'/Graph_`out_var'.png" , replace
		file write graphwriter "\begin{figure}" _n
		file write graphwriter "\caption{Figure with means over time: }" _n
		file write graphwriter "\includegraphics[scale=0.6]{`figure_path'Graph_`out_var'.png}" _n
		file write graphwriter "\end{figure}" _n _n		
		}
		

	di "`SNA_variables'  `further_SN_vars'  "	
	foreach SNA_var in  `SNA_variables'  `further_SN_vars'  {
		* by time_var, sort: egen mean_`SNA_var'= mean(`SNA_var')
		twoway (line  mean_`SNA_var' time_var ) ( line p10_`SNA_var' time_var )/*
			*/ (line  p90_`SNA_var' time_var ), saving(`figure_path'/wiki_3lines_`SNA_var'.gph, replace) /*
		*/ legend(cols(1) size(small)) yticks(#3) ylabel(#4, alternate) /// yscale(off)
		
		graph export "`figure_path'/Graph_`SNA_var'.png" , replace
		file write graphwriter "\begin{figure}" _n
		file write graphwriter "\caption{Figure with means over time: }" _n
		file write graphwriter "\includegraphics[scale=0.6]{`figure_path'Graph_`SNA_var'.png}" _n
		file write graphwriter "\end{figure}" _n
		file write graphwriter " " _n
		}

restore	
	
	di "`SNA_variables'  `further_SN_vars'  "
	graph combine  /* ///  
		`figure_path'/wiki_3lines_num_authors.gph ///
		`figure_path'/wiki_3lines_`length_bytes'.gph */ /// 
		`figure_path'/wiki_3lines_SNwik_degree.gph ///
		`figure_path'/wiki_3lines_SNwik_rank_closeness.gph ///
		`figure_path'/wiki_3lines_SNcat_degree.gph ///
        `figure_path'/wiki_3lines_SNcat_rank_closeness.gph, ///
                title("Network Variables' development over time") ///
				subtitle("`panel_subtitle' `truncation_note'") ///
				rows(3)

* graph export Distribution_of_Main_Variables.png, replace	
graph export `figure_path'/Development_SN_Vars.`figformat', replace
!epstopdf `figure_path'/Development_SN_Vars.`figformat'

		file write graphwriter "\begin{figure}" _n
		file write graphwriter "\caption{Figure with means over time: }" _n
		file write graphwriter "\includegraphics[scale=0.8]{`figure_path'/Development_SN_Vars.pdf}" _n
		file write graphwriter "\end{figure}" _n
		file write graphwriter " " _n
				
	graph combine ///  
		`figure_path'/wiki_3lines_num_authors.gph ///
		`figure_path'/wiki_3lines_`length_bytes'.gph,  /// 
                title("Main Outcomes' development over time") ///
				subtitle("`panel_subtitle' `truncation_note'") ///
				rows(3)

graph export `figure_path'/Development_Outcomes.`figformat', replace
!epstopdf `figure_path'/Development_Outcomes.`figformat'
	
	
		file write graphwriter "\begin{figure}" _n
		file write graphwriter "\caption{Figure with means over time: }" _n
		file write graphwriter "\includegraphics[scale=0.8]{`figure_path'/Development_Outcomes.pdf}" _n
		file write graphwriter "\end{figure}" _n
		file write graphwriter " " _n
				
file close graphwriter



************************
* Comparing two Groups
************************

local group_var /* variable_by_which_to_group */
local val0
local val1
		
/* scatterplots plain over time */

foreach var in `content_vars' {
 twoway (scatter `var' `time_var' if `group_var' == `val0', msize(tiny) jitter(4)) /*
	*/ (lfit `var' `time_var' if `group_var' == `val0') /*
	*/ (scatter `var' `time_var' if `group_var' == `val1', msize(tiny) jitter(4)) /*
	*/ (lfit `var' `time_var' if `group_var' == `val1') /*
	*/ , title("`var' vs. time") subtitle("`bycat_scatter_time_subtitle'") /*
	*/ legend(label(2 "`group_var'=`val0'") label(4 "`group_var'=`val1'"))/*
	*/ ${nodraw} saving(${PATH_MKM_MORE_FIGS}/by_cat_scatter_`var'_vs_time_var.gph, replace)	

	*graph export ${PATH_MKM_MORE_FIGS}/by_cat_scatter_`var'_vs_time_var.`figformat', replace
	
	${show_results}
}


/* degree centrality vs. x - How does degree centrality correlate with content vars and x*/

local x_var 		/* rhs_variable_of_interest */


local bycat_scatter_`x_var'_subtitle "scatter of the variable `var' vs. `x_var' by category."

foreach var in `core_outcomes' `etc' {
 twoway (scatter `var' `x_var' if `group_var' == `val0', msize(tiny) jitter(4)) /*
	*/ (lfit `var' `x_var' if `group_var' == `val0') /*
	*/ (scatter `var' `x_var' if `group_var' == `val1', msize(tiny) jitter(4)) /*
	*/ (lfit `var' `x_var' if `group_var' == `val1'), /*			
	*/ title("`var') vs. `x_var'") subtitle("`bycat_scatter_`x_var'_subtitle'") /*
	*/ legend(label(2 "`group_var'=`val0'") label(4 "`group_var'=`val1'"))/*
	*/ ${nodraw} saving(${PATH_MKM_MORE_FIGS}/by_cat_scatter_`SN_Position'_vs_`var'.gph, replace)

* graph export ${PATH_MKM_MORE_FIGS}/by_cat_scatter_`SN_Position'_vs_`var'.png, replace
* !epstopdf ${PATH_MKM_MORE_FIGS}/by_cat_scatter_`var'_time_var.`figformat'
}	
	
******************************
* Graph combines with filewriter
******************************

local graph_includer_file ""
* file open graphwriter using "`path_output'`graph_includer_file'" , write replace


** figures with outcomes
	
	local a_values clicks page_length
	
	local crit_b flag_treated
	local b_values 0 1
	local crit_c placebo_state
	local c_values 0 1
	
	/* depending where you add one more criterion you get a*b*c graphs rather than 4 graphs (curently) */ 
	foreach crit_a in `a_values' {
		bys time_var `crit_b' `crit_c' : egen mean_`crit_a' = mean(`crit_a')
		
		foreach b_value in `b_val_0' `b_val_1' {
			foreach c_value in `c_val_0' `c_val_1' {
				*running index: 
				local idx = `idx' + 1
				*mean variable:
				
				scatter mean_`crit_a' time_var if `crit_b' == `b_value' & `crit_c' == `c_value' 
					/* Note: this produces maxidx= a*b*c scatters and saves them as graph_1.gph to graph_maxidx.gph */
				graph save graph_`idx', replace
				sleep `viewtime'

			}
		}
	}
	
	*** 4 Outcomes
	
	local combi_figure_name "test_figure"
	local panel_subtitle "" /* Hier kann ein subtitle stehen*/ 
	local truncation_note ""
	local titletext "Network Variables' development for connected and jumping articles"
	
	di "`SNA_variables'  `further_SN_vars'  "

	
	graph combine   ///  
		`figure_path'graph_1.gph ///
		`figure_path'graph_2.gph  ///
		`figure_path'graph_3.gph ///
		`figure_path'graph_4.gph ///
                , title(`titletext') ///
				subtitle("`panel_subtitle' `truncation_note'") ///
				rows(3) ysize(16) xsize(16) iscale(0.6)  graphregion(margin(l=0 r=0 t=0 b=0)) /*ycommon xcommon */

	* graph export `figure_path'/`combi_figure_name'.`figformat', replace
	* !epstopdf `figure_path'/`combi_figure_name'.`figformat'

sleep `longview'

		file write `file_includer' "\begin{figure}" _n
		file write `file_includer' "\begin{center}" _n
		file write `file_includer' "\caption{Figure with means of `crit_a' over time: comparing the groups 2x2}" _n
		file write `file_includer' "\includegraphics[scale=0.3]{`figure_path'/`combi_figure_name'.pdf}" _n
		file write `file_includer' "\end{center}" _n
		file write `file_includer' "\end{figure}" _n
		file write `file_includer' " " _n
	
	
exit
	*** 6 Outcomes for fun
	
	local combi_figure_name "Bonus_6_connected_vs_jumpers_over_time"
	local panel_subtitle "" /* Hier kann ein subtitle stehen*/ 
	local truncation_note ""
	local titletext "Network Variables' development for connected and jumping articles"
	
	di "`SNA_variables'  `further_SN_vars'  "
	graph combine   ///  
		`figure_path'/wiki_2groups_num_authors.gph ///
		`figure_path'/wiki_2groups_`length_bytes'.gph  ///
		`figure_path'/wiki_2groups_SNwik_degree.gph ///
		`figure_path'/wiki_2groups_SNwik_rank_closeness.gph ///
		`figure_path'/wiki_2groups_SNcat_degree.gph ///
        `figure_path'/wiki_2groups_SNcat_rank_closeness.gph ///
                , title() ///
				subtitle("`panel_subtitle' `truncation_note'") ///
				rows(3) ysize(16) xsize(16) iscale(0.6)  graphregion(margin(l=0 r=0 t=0 b=0)) 

	* graph export Distribution_of_Main_Variables.png, replace	
	graph export `figure_path'/`combi_figure_name'.`figformat', replace
	!epstopdf `figure_path'/`combi_figure_name'.`figformat'

		file write `file_includer' "\begin{figure}" _n
		file write `file_includer' "\caption{Figure with means over time: The Figure shows the development of the p50 of the Network Variables in the connected and the smaller jumping sample over time.}" _n
		file write `file_includer' "\includegraphics[scale=0.4]{`figure_path'/`combi_figure_name'.pdf}" _n
		file write `file_includer' "\end{figure}" _n
		file write `file_includer' " " _n
	
	
	** figure with outcomes
		
	local combi_figure_name "Paper_outcomes_conn_vs_jump_over_time"
	local panel_subtitle "" /*Hier wre ein titel mglich*/
	local truncation_note ""
	local titletext "Network Variables' development for connected and jumping articles"
	
	
	
	graph combine ///  
		`figure_path'/wiki_2groups_num_authors.gph ///
		`figure_path'/wiki_2groups_`length_bytes'.gph  /// 
		`figure_path'/wiki_2groups_is_disconn.gph, ///
                title("") ///
				subtitle("`panel_subtitle' `truncation_note'") ///
				rows(3) ysize(16) xsize(12) iscale(0.7)  graphregion(margin(l=0 r=0 t=0 b=0)) 

	graph export `figure_path'/`combi_figure_name'.`figformat', replace
	!epstopdf `figure_path'/`combi_figure_name'.`figformat'
	
	
		
		file write `file_includer' "\begin{figure}" _n
		file write `file_includer' "\centering" _n
		file write `file_includer' "\caption{ Figure with means over time: The Figure shows the development of the p50 of the connected and the smaller jumping sample over time. }" _n
		file write `file_includer' "\includegraphics[scale=0.4]{`figure_path'/`combi_figure_name'.pdf}" _n
		file write `file_includer' "\end{figure}" _n
		file write `file_includer' " " _n
	
				
*************************
* close descriptives caller
*************************
	
	file write `file_includer' "\clearpage"
	file close `file_includer'


	
	
clear
${memory_unuse}
${processors_unuse}

*** long description of do_file
/* This do file ...
long_descritpion_end ***/

log close
