
/*********** PLUGIN FILE: wikidis_plugin_addvars **************/

* no log is written as this file is not intended to run independently
*** ADAPT FROM WIKIPEDIA-PROJECT!! 

/*** Short description:
This do file adds variables that might be needed for regressions or descriptives on the fly.
	=> The variables added here are not considered to be important enough to be on the main data, but as they should be the same
	across regressions and descriptives, they are centrally distributed.
***/

	include "${PATH_PLUGIN}wikidis_plugin_locals.do"
		
	if "`i_need_page_titles_yes'" == "yes" {
	* add page_titles => sollen wir die mit einer local optional setzen?
	
	merge m:1 page_id using ${PATH_DISASTER_DATA}wiki`DisPod'_page_titles.dta
	drop if _merge==2
	drop _merge
	}


*** delta variables

if "`i_need_delta_vars_yes'" == "yes" {

	sort mkm_id time_var
	xtset mkm_id time_var

	cap drop del*
	
	by mkm_id: gen del_page_length = page_length[_n+1] - page_length[_n]
	by mkm_id: gen del_num_authors = num_authors[_n+1] - num_authors[_n]
	by mkm_id: gen del_num_revisions = num_revisions[_n+1] - num_revisions[_n]
	by mkm_id: gen del_num_refs = num_refs[_n+1] - num_refs[_n]
	by mkm_id: gen del_num_imagelinks = num_imagelinks[_n+1] - num_imagelinks[_n]
	by mkm_id: gen del_num_extlinks = num_extlinks[_n+1] - num_extlinks[_n]
	by mkm_id: gen del_SNwik_degree = SNwik_degree[_n+1] - SNwik_degree[_n]


	
	gen del2_page_length = d.page_length
	gen del2_num_authors = d.num_authors
	gen del2_num_revisions = d.num_revisions
	gen del2_num_refs = d.num_refs
	gen del2_num_imagelinks = d.num_imagelinks
	gen del2_num_extlinks = d.num_extlinks
	gen del2_SNwik_degree = d.SNwik_degree

	
	}
	
	
*** further variables for regression:
	
if "`i_need_regressions_vars_yes'" == "yes" {


	*** time dummies
		tab time_var,gen(time_period)

	*** Diff in Diff Variables
		gen post_shock = time_var > 0
		gen shock_x_real = post_shock*(placebo_state == 0)
		gen shock_x_treatment = post_shock*flag_treated
		
	*** time_dummy_x_treatment
		gen flag_real_treatment = flag_treated&(placebo_state==0)
		
		forvalues i = 1/29 {		
			gen realtreat_x_period_`i' = flag_real_treatment*time_period`i'
			}

	*** collector-dummies for gathering several cross-terms
	gen realtreat_x_neg_week2 			= 	flag_real_treatment*(time_var < -7)
	gen realtreat_x_days_neg7_to_neg4 	= 	flag_real_treatment*(time_var >= -7 & time_var < -3)	
	gen realtreat_x_days_neg3_to_neg1 	= 	flag_real_treatment*(time_var >= -3 & time_var <  0)	
	gen realtreat_x_days_3_to_6 		= 	flag_real_treatment*(time_var >=  3 & time_var <  7)	
	gen realtreat_x_days_7_to_14 		= 	flag_real_treatment*(time_var >= 7)	
	
	cap label var realtreat_x_neg_week2 			"Before: days -14 to -8"
	cap label var realtreat_x_days_neg7_to_neg4	"Before: days - 7 to -4"
	cap label var realtreat_x_days_neg3_to_neg1	"Before: days - 3 to -1"
	cap label var realtreat_x_days_3_to_6			"After: days 3 to  6"
	cap label var realtreat_x_days_7_to_14		"After: days 7 to 14 "


		
	* day of week
	
	if 	"${DATAWAVE}" >= "4" {
	
		gen day_of_week = .

		gen day_of_week_help = eve_day_of_week + time_var 
		gen weeks_away  = .
		replace weeks_away  = int((day_of_week_help-1)/7) if day_of_week_help > 0
		replace weeks_away  = int((day_of_week_help)/7)-1 if day_of_week_help <= 0
		
		
		replace day_of_week = eve_day_of_week if time_var == 0
		replace day_of_week = day_of_week_help - (weeks_away*7)  if time_var > 0
		replace day_of_week = day_of_week_help - (weeks_away*7)  if time_var < 0
		
		
		* sum day_of_week eve_day_of if time_var >= 0 & time_var == 7 
		sum day_of_week

		tab day_of_week, gen(weekday_)
		local weekday_dummies "weekday_2-weekday_7"

	}

	* quickfix for "dis-data" fix this
	if ("`DisPod'" == "dis") & ("${DATAWAVE}" < "4") {
		gen wekday_1 = (time_var == -7) | (time_var == 1)
		gen wekday_2 = (time_var == -6) | (time_var == 2)
		gen wekday_3 = (time_var == -5) | (time_var == 3)
		gen wekday_4 = (time_var == -4) | (time_var == 4)
		gen wekday_5 = (time_var == -3) | (time_var == 5)
		gen wekday_6 = (time_var == -2) | (time_var == 6)
		gen wekday_7 = (time_var == -1) | (time_var == 7)
	}

	/*
	order page_id placebo_state time_var day_of* weeks_
	order eve_day_of_week
	sort page_id placebo_state time_var 
	`browse'

	*/
	}
	
	if "`i_need_spill_heterogeneity_vars'" == "yes" {
		gen flag_stub = .
		replace flag_stub = 1 if page_length <= 1500 & time_var==0
		replace flag_stub = 0 if page_length > 1500 & time_var==0
		bys page_id placebo_state: egen flag_stub_at_0 = max(flag_stub)

		replace flag_stub = (page_length <= 1500)

		gen flag_long = (page_length > 9500)
		gen flag_linked = (SNwik_degree > 75)
		gen flag_super_l1 = (num_links_from_l1 > 5)		
		sum flag*
	}
	

		
exit

*** ADAPT FROM WIKIPEDIA-PROJECT!! 
